$(function() {
	// 初始化容器宽高
	$(".mui-content").height($(window).height() - $('header').css('height').replace('px', ''))
	
	mui.init({
		swipeBack: false, //启用右滑关闭功能
		gestureConfig: {
			tap: true, //默认为true
			doubletap: true, //默认为false
			longtap: true, //默认为false
			swipe: true, //默认为true
			drag: false, //默认为true
			hold: false, //默认为false，不监听
			release: false //默认为false，不监听
		}
	})
	
	// 初始化地图
	var map = GIS.init()
	map.on('load', function() {
		GIS.utils.addBlankGeoJSONSource('geojson-point')
		
		map.addLayer({
			id: 'geojson-text',
			source: 'geojson-point',
			type: "symbol",
			layout: {
				"text-size": 14,
				"text-field": "{text}",
				"text-font": ["Microsoft YaHei"],
				"text-allow-overlap": true,
				"text-ignore-placement": true
			},
			paint: {
				"text-color": '#fff',
				"text-halo-width": 10,
				"text-halo-color": { 
					"type": "identity", 
					"property": "color"
				},
			}
		})
		
		// “霾” 需要单独构建一个图层
		map.addLayer({
			id: 'geojson-icon',
			source: 'geojson-point',
			type: "symbol",
			layout: {
				"visibility": "none",
				"icon-size": 0.4,
				"icon-image": "{icon}",
				"icon-allow-overlap": true,
				"icon-ignore-placement": true
			}
		})
		
		loadData()
	})

	// 点击事件
	var popup
	map.on('click', 'geojson-icon', pointClickEvent)
	map.on('click', 'geojson-text', pointClickEvent)
	function pointClickEvent(e) {
		var feature = e.features[0]
		popup = new mapboxgl.Popup()
            .setLngLat(feature.geometry.coordinates)
            .setHTML(feature.properties.popup)
			.addTo(map)
	}
	
	// 根据选中的条件切换数据源
	function changeMapSource() {
		popup && popup.remove()
		var legend = $('.ele-datehour-option.datehour-option-active').data('legend')
		var type = $('.ele-datehour-option.datehour-option-active').data('type')
		var hour = $('.envir-datehour-item.datehour-option-active').data('val')
		$('#envirRealTime').text(dayjs(page.times[legend]).add(hour - 24, 'hour').format('MM月DD日HH时') + '至' + dayjs(page.times[legend]).add(hour, 'hour').format('MM月DD日HH时'))
		map.getSource('geojson-point').setData(page[legend][type][hour])
	}
	
	// 请求数据并处理成geojson
	var page = { times: {} }
	function loadData(legend, needSyncMap) {
		legend = legend || $('.ele-datehour-option.datehour-option-active').data('legend')
		if (page[legend] && page[legend].startTime === page.times[legend]) {
			if (needSyncMap != false) {
				changeMapSource()
			}
			return
		}
		
		var url, storageDataKey, storageTimeKey
		if (legend === 'haze') {
			// 霾
			url = '/environment/forecast/getPeno'
			storageDataKey = 'storagePhenomenaResData'
			storageTimeKey = 'phenomenaStartTime'
		} else if (legend === 'level') {
			// 气象条件
			url = '/environment/forecast/getWea'
			storageDataKey = 'storageWeatherConditionsData'
			storageTimeKey = 'weatherCondStartTime'
		} else {
			// 空气质量
			url = '/environment/forecast/getAirQuality'
			storageDataKey = 'storageAirqualityData'
			storageTimeKey = 'airqualityStartTime'
		}
		
		ajax(url, {
			startTime: page.times[legend] || ''
		}, function(res) {
			var features = { [legend]: {} }, hours = [24, 48, 72], time = res.body.startTime

			// 缓存最新数据时间
			if (!$('#nextTimeBtn').data('time' + legend)) {
				$('#nextTimeBtn').data('time' + legend, time)
			}

			if (legend === 'haze') {
				// 霾
				var items = ['haze']
				items.forEach(function(v) {
					hours.forEach(function(h) {
						features[legend][v] ? features[legend][v][h] = [] : features[legend][v] = { [h]: [] }
					})
				})
				
				res.body.data.forEach(function(item) {
					item.weatherData.forEach(function(a) {
						items.forEach(function(key) {
							var popup = [
								'<div class="custom-popup">',
								'<div class="popup-row"><span class="popup-title">站名：</span>' + item.city + ' ' + item.name + '</div>',
								'<div class="popup-row"><span class="popup-title">' + $('.ele-datehour-option[data-type=' + key + ']').html() + '：</span>' + texts[key](a[key]) + '</div>',
								'<div class="popup-row"><span class="popup-title">能见度：</span>' + a.vis + 'km</div>',
								'<div class="popup-row"><span class="popup-title">相对湿度：</span>' + (a.rhu * 100) + '%</div>',
								'</div>'
							]

							features[legend][key][a.dateHour] && features[legend][key][a.dateHour].push({
								"type": "Feature",
								"geometry": {
									"type": "Point",
									"coordinates": [Number(item.lon), Number(item.lat)]
								},
								"properties": {
									// TODO: 霾等级图标
									"icon": 'haze-' + a[key],
									"popup": popup.join('')
								}
							})
						})
					})
				})
			} else if (legend === 'level') {
				// 气象条件
				var colors = ["#2af744", "#e4f439", "#df9441", "#f20d08", "#a01856", "#7b0225"]
				var items = ['level']
				items.forEach(function(v) {
					hours.forEach(function(h) {
						features[legend][v] ? features[legend][v][h] = [] : features[legend][v] = { [h]: [] }
					})
				})
				
				res.body.data.forEach(function(item) {
					item.weatherConditionData.forEach(function(a) {
						items.forEach(function(key) {
							if (a.meteCondLevel === 'null' || !a.meteCondLevel) {
								return
							}

							var popup = [
								'<div class="custom-popup">',
								'<div class="popup-row"><span class="popup-title">站名：</span>' + a.city + ' ' + a.name + '</div>',
								'<div class="popup-row"><span class="popup-title">' + $('.ele-datehour-option[data-type=' + key + ']').html() + '：</span>' + a.meteCondLevel + '级</div>',
								'</div>'
							]

							features[legend][key][a.dateHour] && features[legend][key][a.dateHour].push({
								"type": "Feature",
								"geometry": {
									"type": "Point",
									"coordinates": [Number(a.lon), Number(a.lat)]
								},
								"properties": {
									"text": a.meteCondLevel + '级',
									"color": colors[a.meteCondLevel - 1] || '#adadad',
									"popup": popup.join('')
								}
							})
						})
					})
				})
			} else {
				// 空气质量
				var items = ['o3', 'aqi', 'pm25', 'pm10']
				items.forEach(function(v) {
					hours.forEach(function(h) {
						features[legend][v] ? features[legend][v][h] = [] : features[legend][v] = { [h]: [] }
					})
				})
				
				res.body.data.forEach(function(item) {
					var station = getStationByCode(item.stationCode)
					item.airData.forEach(function(a) {
						if (!a.lon) {
							return
						}
						
						items.forEach(function(key) {
							var value = a[key]
							if (value >= 9999) {
								return
							}

							var popup = [
								'<div class="custom-popup">',
								'<div class="popup-row"><span class="popup-title">站名：</span>' + station.city + ' ' + station.name + '</div>',
								'<div class="popup-row"><span class="popup-title">' + $('.ele-datehour-option[data-type=' + key + ']').html() + '：</span>' + value + '</div>',
								key === 'aqi' ? '<div class="popup-row"><span class="popup-title">首要污染物：</span>' + a.primaryPollutant + '</div>' : '',
								'</div>'
							]

							features[legend][key][a.dateHour].push({
								"type": "Feature",
								"geometry": {
									"type": "Point",
									"coordinates": [Number(a.lon), Number(a.lat)]
								},
								"properties": {
									"text": value,
									"popup": popup.join(''),
									"color": getAQIPollutionColor(key === 'aqi' ? value : iaqi[key](value))
								}
							})
						})
					})
				})
			}

			page.times[legend] = res.body.startTime || page.times[legend]
			page[legend] = { startTime: res.body.startTime }
			
			// 设置缓存，用于排位页面的数据展示
			localStorage.setItem(storageDataKey, res.body.data.length === 0 ? null : JSON.stringify(res.body.data))
			localStorage.setItem(storageTimeKey, page.times[legend])
			
			for (var templegend in features) {
				if (!page[templegend]) {
					page[templegend] = {}
				}
				
				for (var type in features[templegend]) {
					if (!page[templegend][type]) {
						page[templegend][type] = {}
					}
				
					for (var hour in features[templegend][type]) {
						page[templegend][type][hour] = {
							type: "FeatureCollection",
							features: features[templegend][type][hour]
						}
					}
				}
			}
			
			if (needSyncMap != false) {
				changeMapSource()
			}
		})
	}
	
	/**
	 * 根据AQI获取污染浓度颜色
	 */
	function getAQIPollutionColor(aqi) {
		var colors = ['#6ec128', '#dfcb3a', '#fb5e28', '#e50424', '#851054', '#3e0856']
		
		if (aqi < 51) {
			return colors[0]
		}
		
		if (aqi >= 51 && aqi <= 100) {
			return colors[1]
		}
		
		if (aqi >= 101 && aqi <= 150) {
			return colors[2]
		}
		
		if (aqi >= 151 && aqi <= 200) {
			return colors[3]
		}
		
		if (aqi >= 201 && aqi <= 300) {
			return colors[4]
		}
		
		if (aqi > 300) {
			return colors[5]
		}
		
		return '#FFFFFF'
	}

	var iaqi = {
		pm25: function(val) {
			if (val < 35) {
				return 50 * (val - 0) / 35 + 0
			} else if (val < 75) {
				return 50 * (val - 35) / 40 + 50
			} else if (val < 115) {
				return 50 * (val - 75) / 40 + 100
			} else if (val < 150) {
				return 50 * (val - 115) / 35 + 150
			} else if (val < 250) {
				return 100 * (val - 150) / 100 + 200
			} else if (val < 350) {
				return 100 * (val - 250) / 100 + 300
			} else if (val < 500) {
				return 100 * (val - 350) / 150 + 400
			} else {
				return 100 * (500 - 350) / 150 + 400
			}
		},
		pm10: function(val) {
			if (val < 50) {
				return 50 * (val - 0) / 50 + 0
			} else if (val < 150) {
				return 50 * (val - 50) / 100 + 50
			} else if (val < 250) {
				return 50 * (val - 150) / 100 + 100
			} else if (val < 350) {
				return 50 * (val - 250) / 100 + 150
			} else if (val < 420) {
				return 100 * (val - 350) / 70 + 200
			} else if (val < 500) {
				return 100 * (val - 420) / 80 + 300
			} else if (val < 600) {
				return 100 * (val - 500) / 100 + 400
			} else {
				return 100 * (600 - 500) / 150 + 400
			}
		},
		o3: function(val) {
			if (val < 160) {
				return 50 * (val - 0) / 160 + 0
			} else if (val < 200) {
				return 50 * (val - 160) / 40 + 50
			} else if (val < 300) {
				return 50 * (val - 200) / 100 + 100
			} else if (val < 400) {
				return 50 * (val - 300) / 100 + 150
			} else if (val < 800) {
				return 100 * (val - 400) / 400 + 200
			} else if (val < 1000) {
				return 100 * (val - 800) / 200 + 400
			} else if (val < 1200) {
				return 100 * (val - 1000) / 200 + 400
			} else {
				return 100 * (1200 - 1000) / 200 + 400
			}
		}
	}

	var texts = {
		haze: function(level) {
			if (level == 1) {
				return '轻度霾'
			} else if (level == 2) {
				return '中度霾'
			} else if (level == 3) {
				return '重度霾'
			} else {
				return '无'
			}
		}
	}
	
	// 时次切换
	$('#envirDateHourUl .envir-datehour-item').click(function() {
		$(this).addClass('datehour-option-active').siblings().removeClass('datehour-option-active')
		
		var legend = $('.ele-datehour-option.datehour-option-active').data('legend')
		var type = $('.ele-datehour-option.datehour-option-active').data('type')
		var hour = $(this).data('val')
		
		changeMapSource(legend, type, hour)
	})
	
	// 要素切换
	$('#rain-datehour-ul .ele-datehour-option').click(function() {
		var type = $(this).data('type')
		var legend = $(this).data('legend')
			
		$(this).addClass("datehour-option-active").siblings().removeClass("datehour-option-active")
		$("#envir-legend").attr("src", '../../images/monitoringOfLive/envir-' + legend + '.png')
		
		if (legend === 'haze') {
			// 霾
			map.setLayoutProperty('geojson-text', 'visibility', 'none')
			map.setLayoutProperty('geojson-icon', 'visibility', 'visible')
		} else if (legend === 'level') {
			// 气象条件
			map.setLayoutProperty('geojson-icon', 'visibility', 'none')
			map.setLayoutProperty('geojson-text', 'visibility', 'visible')
		} else {
			// 空气质量
			map.setLayoutProperty('geojson-icon', 'visibility', 'none')
			map.setLayoutProperty('geojson-text', 'visibility', 'visible')
		}
		
		loadData()
	})
	
	// 色标图例显示隐藏切换
	$("#envir-conent").on("click","#environmental-legend-box",function(e){
		var legend = $('.ele-datehour-option.datehour-option-active').data('legend')
		$("#envir-legend").attr("src", '../../images/monitoringOfLive/envir-' + legend + '.png')
		$("#envir-legend").toggle()
		//防止点击到翻页按钮
		e.stopPropagation()
	});
	
	// 下一个时次
	$('#nextTimeBtn').click(function() {
		var legend = $('.ele-datehour-option.datehour-option-active').data('legend')
		var maxTime = $(this).data('time' + legend)
		var nextTime = dayjs(page.times[legend]).add(12, 'hour')

		if (maxTime && dayjs(maxTime).isBefore(nextTime)) {
			mui.alert('已是最新数据！')
			return
		}

		page.times[legend] = nextTime.format('YYYY-MM-DD HH:mm:ss')
		loadData()
	})
	
	// 上一个时次
	$('#prevTimeBtn').click(function() {
		var legend = $('.ele-datehour-option.datehour-option-active').data('legend')
		page.times[legend] = dayjs(page.times[legend]).add(-12, 'hour').format('YYYY-MM-DD HH:mm:ss')
		loadData()
	})
	
	// 查看排位
	$("#environmental-rank-link").click(function() {
		// 强制加载所有数据，用于排位页面的数据展示
		;['a', 'haze', 'level'].forEach(function(legend) {
			loadData(legend, false)
		})
		
		// 缓存选中的数据条件，用于排位页面的数据展示
		localStorage.activeEleType = parseInt($(".ele-datehour-option.datehour-option-active").data("classify"))
		localStorage.activeHourType = $(".envir-datehour-item.datehour-option-active").data("val")
		localStorage.activeEleTxt = $(".ele-datehour-option.datehour-option-active").data("type")
		
		mui.openWindow({
			url:'../forecastInfo/envirForecastRank.html',
			styles: {
				statusbar: {
					background: localStorage.statusbarColor
				}
			}
		})
	})
})