$(function () {
	// 初始化容器宽高
	var headerHeightCss = $('header').css('height')
	$(".mui-content").height($(window).height() - headerHeightCss.replace('px', ''))
	$('.rain-select').css('top', 'calc(58px + ' + headerHeightCss + ')').show()

	mui.init({
		swipeBack: false,
		gestureConfig: {
			tap: true,
			doubletap: true,
			longtap: true,
			swipe: true,
			drag: true,
			hold: false,
			release: false
		}
	})

	// 初始化地图
	var map = GIS.init({
		spot: true
	})
	map.on('load', function () {
		GIS.utils.addBlankGeoJSONSource('spotGeoJSON')
		GIS.utils.addBlankGeoJSONSource('pointGeoJSON')
		map.addLayer({
			id: 'spotGeoJSON',
			source: 'spotGeoJSON',
			type: "fill",
			paint: {
				"fill-color": {
					"type": "identity",
					"property": "color"
				},
				"fill-opacity": 1
			},
		}, 'city-boundary')

		// 将所有的颜色绘制成MapBox能识别的矢量图片
		var colors = ["#ffffff", "#A3F48B", "#35AB00", "#61B9F9", "#0403FF", "#FA00FA", "#810042", "#0000ff", "#00a6ff", "#00ffb5", "#00ff08", "#94ff00", "#ffc300", "#ff2c00", "#52478d", "#554eb1", "#5057b8", "#4369c4", "#40a0b4", "#4ec167", "#68d14f", "#9ddd44", "#000000", "#f017af", "#f503b4", "#f74603", "#ff0000", "#ff8200", "#ffff00", "#a4ff00", "#40ff00", "#00ff00", "#00bfff", "#808080", "#8a8a8a", "#949494", "#9e9e9e", "#a8a8a8", "#b2b2b2", "#bcbcbc", "#c6c6c6", "#d0d0d0", "#dadada", "#e4e4e4"]
		colors.forEach(function (color) {
			var gba = GIS.utils.hexToGba(color)

			var width = 42
			var height = 20
			var bytesPerPixel = 4
			var data = new Uint8Array(width * height * bytesPerPixel)

			for (var x = 0; x < width; x++) {
				for (var y = 0; y < height; y++) {
					var offset = (y * width + x) * bytesPerPixel
					data[offset + 0] = gba.red
					data[offset + 1] = gba.green
					data[offset + 2] = gba.blue
					data[offset + 3] = 255
				}
			}

			map.addImage('ci' + color, { width: width, height: height, data: data })
		})

		map.addLayer({
			id: 'pointGeoJSON',
			source: 'pointGeoJSON',
			type: "symbol",
			layout: {
				"text-size": 14,
				"text-field": "{val}",
				"text-font": ["Microsoft YaHei"],
				"text-allow-overlap": false,
				"text-ignore-placement": false,
				"icon-image": "ci{color}",
				"visibility": "none"
			},
			paint: {
				"text-halo-width": 1.5,
				"text-halo-color": '#ffffff'
			}
		})

		loadData()
	})

	map.on('click', function (e) {
		if (!GIS.utils.contain(e.lngLat.lng, e.lngLat.lat)) {
			return
		}

		loadGridData(e.lngLat.lng + ',' + e.lngLat.lat)
	})

	var currentFilterStep = 10
	map.on('zoomend', function (e) {
		var zoom = map.getZoom()

		for (var max = 10.5, min = 5.5; max >= min; max -= 1) {
			var step = 1

			switch (max) {
				case 5.5:
					step = 10
					break
				case 6.5:
					step = 8
					break
				case 7.5:
					step = 6
					break
				case 8.5:
					step = 4
					break
				case 9.5:
					step = 2
					break
				default:
					step = 1
					break
			}

			if (zoom > max) {
				if (currentFilterStep === step) {
					return
				}

				currentFilterStep = step
				return map.getSource('pointGeoJSON').setData({
					"type": "FeatureCollection",
					"features": filterFeatures(currentFilterStep)
				})
			}
		}
	})

	/**
	 * 点击 Marker
	 */
	$('#map').on('touchstart', '.mapboxgl-marker', function (e) {
		e.stopPropagation()
		e.preventDefault()

		if ($('.mapboxgl-popup').length === 0) {
			$("#chart-box").show()
		} else {
			$("#chart-box").hide()
		}
		window.singleMarker && window.singleMarker.togglePopup()
	})

	/**
	 * 搜索地名或经纬度
	 */
	$("#girdding-search").on('input', debounce(function () {
		loadGridData($(this).val())
	}, 500))

	//温度、云量折线图切换
	$("#switchChartBtn").on('tap', function () {
		var temChartBox = $("#temChartBox"),
			humidityChartBox = $("#humidityChartBox");
		if (temChartBox.hasClass('active-box')) {
			temChartBox.removeClass('active-box').siblings().addClass('active-box')
			$(this).text('温度降水风速')
		} else {
			humidityChartBox.removeClass('active-box').siblings().addClass('active-box')
			$(this).text('相对湿度、云量')
		}
	})

	/**
	 * 查询加载格点数据
	 */
	function loadGridData(query) {
		GIS.utils.geocoderSearch(query, function (res) {
			if (!res) {
				mui.toast("查询暂无结果...")
				return
			}

			var point = res.location.split(',')
			var popup = new mapboxgl.Popup()
				.setLngLat(point)

			http.get('/forecastMonitor/gridForecast/singleGridChart.do', {
				lon: point[0],
				lat: point[1]
			}, function (data) {
				if (data.body.total == 0) {
					$("#chart-box").hide();
					return false;
				}
				$("#chart-box").show();

				var resData = data.body.data;
				var cloudArr = [],
					preArr = [],
					rhuArr = [],
					temArr = [],
					pphArr = [],
					tmaxArr = [],
					tminArr = [],
					windDirectionArr = [],
					windSpeedArr = [],
					xAixsTime = [],
					cloudNumArr = [],
					preNumArr = [],
					rhuNumArr = [],
					temNumArr = [],
					pphNumArr = [],
					tmaxNumArr = [],
					tminNumArr = [],

					windDirectionNumArr = [],
					windSpeedNumArr = [],
					resStartTime, xAixsTimeItemDetails;

				resStartTime = data.body.props.startTime;
				cloudArr = resData.cloud;
				preArr = resData.pre;
				rhuArr = resData.rhu;
				erhaArr = resData.erha;
				erhiArr = resData.erhi;
				temArr = resData.tem;
				pphArr = resData.pph;
				tmaxArr = resData.tmax;
				tminArr = resData.tmin;
				windDirectionArr = resData.windDirection;
				windSpeedArr = resData.windSpeed;

				for (var i = 0; i < preArr.length; i++) {
					cloudNumArr.push(Number(cloudArr[i]));
					preNumArr.push(Number(preArr[i]));
					rhuNumArr.push(Number(rhuArr[i]));
					temNumArr.push(Number(temArr[i]));
					pphNumArr.push(Number(pphArr[i]));
					windDirectionNumArr.push(Number(windDirectionArr[i]));
					windSpeedNumArr.push(Number(windSpeedArr[i]));
				}

				// 最大最小温度
				for (var i = 0; i < tmaxArr.length; i++) {
					tmaxNumArr.push(Number(tmaxArr[i]));
					tminNumArr.push(Number(tminArr[i]));
				}

				// 3小时数据数组拆分成白天晚上数组
				function hourArrSplitDayArr(newArrName, arrData) {
					newArrName = []
					for (var i = 0, len = arrData.length; i < len; i += 4) {
						newArrName.push(arrData.slice(i, i + 4));
					}
					return newArrName
				}

				var dataLength = preArr.length;
				var screenWeight = $(window).width();
				$(".release-time").text(resStartTime.substr(0, 16));
				markerData = []; //清空数组
				$('#time-weather-list').empty() //清空弹出框天气信息
				$('#weather-wind-list').empty() //清空弹出框天气信息

				//通过3小时计算每日日期
				var xAixsTimeItemDayDetails
				var dateTimeStr = resStartTime.replace(/-/g, ",").replace(/ /g, ",").replace(/:/g, ",");
				var xAixsTimeItemDaArr = []
				for (var i = 0; i < dataLength / 8; i++) {
					xAixsTimeItemDay = addHour(resStartTime, (i + 1) * 24 * 60 * 60 * 1000);
					xAixsTimeItemDayDetails = xAixsTimeItemDay.substr(5, 2) + '/' + xAixsTimeItemDay.substr(8, 2);
					xAixsTimeItemDaArr.push(xAixsTimeItemDayDetails)
				}

				for (var i = 0; i < dataLength; i++) {
					var xAixsTimeItem = '',
						markerDetails = {};
					var prText = getPPhPhenomena(pphNumArr[i], cloudNumArr[i], preNumArr[i])
					var windDirectionText = queryWindDirection(windDirectionNumArr[i])
					var windSpeedText = getWindData(windSpeedNumArr[i])[1] + '级'
					xAixsTimeItem = addHour(resStartTime, (i + 1) * 3 * 60 * 60 * 1000);


					markerDetails.rain = preArr[i];
					markerDetails.cloud = cloudArr[i];
					markerDetails.humidity = rhuArr[i];
					markerDetails.tem = temArr[i];
					markerDetails.wind = windSpeedArr[i];
					markerDetails.windDirection = windDirectionArr[i];
					markerDetails.datetime = xAixsTimeItem;
					markerData.push(markerDetails);
					xAixsTimeItemDetails = xAixsTimeItem.substr(8, 2) + '日/' + xAixsTimeItem.substr(11, 2);
					xAixsTime.push(xAixsTimeItemDetails);

					var timeWeatherList = '<li class="time-weather-item">\n' +
						'	<span class="time-data">' + xAixsTimeItemDetails + '</span>\n' +
						'	<span class = "weather-text">' + prText.phenomenonatext + '</span>\n' +
						'	<span class = "weather-icon"> <img src="./../images/new-weather-forecast-icon/day' + prText.phenomenonaCode + '.png"></span>\n' +
						' 	<span class = "weather-rain">' + preNumArr[i] + 'mm</span>\n' +
						' </li> '
					$('#time-weather-list').append(timeWeatherList)

					var weatherWindList = '	<li class="weather-wind-item">\n' +
						'	<span class="weather-wind">' + windDirectionText + '</span>\n' +
						'	<span class="wind-level">' + windSpeedText + '</span>\n' +
						'</li>'
					$('#weather-wind-list').append(weatherWindList)
				}


				// 24小时数据
				var pphNumDayArr = hourArrSplitDayArr('pphNumDayArr', pphNumArr)
				cloudNumDayArr = hourArrSplitDayArr('cloudNumDayArr', cloudNumArr)
				preNumDayArr = hourArrSplitDayArr('preNumDayArr', preNumArr)


				$('#timeWeatherListDay').empty()
				$('#timeWeatherLisNight').empty()


				for (var i = 0; i < pphNumDayArr.length; i++) {
					var cloudNumDayData = dayDataSum(cloudNumDayArr[i]) / 4
					var preNumDayData = dayDataSum(preNumDayArr[i])
					var preTextDay = getPPhDayPhenomena(pphNumDayArr[i], cloudNumDayData, preNumDayData)

					var weeks = ['周天', '周一', '周二', '周三', '周四', '周五', '周六']

					xAixsTimeItemDay = addHour(resStartTime, (i / 2) * 24 * 60 * 60 * 1000);
					xAixsTimeItemDayDetails = xAixsTimeItemDay.substr(5, 2) + '/' + xAixsTimeItemDay.substr(8, 2);
					if (i % 2 === 0) {

						var timeWeatherListDay
						if (i == 0 && resStartTime.substr(11, 2) == '20') {
							timeWeatherListDay = '<li class="time-weather-item">\n' +
								'	<span class="time-data">' + xAixsTimeItemDayDetails + '</span>\n' +
								' 	<span class = "weather-rain">' + weeks[dayjs(xAixsTimeItemDay).format('d')] + '</span>\n' +
								' </li> '
						} else {
							timeWeatherListDay = '<li class="time-weather-item">\n' +
								'	<span class="time-data">' + xAixsTimeItemDayDetails + '</span>\n' +
								' 	<span class = "weather-rain">' + weeks[dayjs(xAixsTimeItemDay).format('d')] + '</span>\n' +
								'	<span class = "weather-text">' + preTextDay.phenomenonatext + '</span>\n' +
								'	<span class = "weather-icon"> <img src="./../images/new-weather-forecast-icon/day' + preTextDay.phenomenonaCode + '.png"></span>\n' +
								' </li> '
						}

						$('#timeWeatherListDay').append(timeWeatherListDay)
					} else {
						var timeWeatherListNight = '<li class="time-weather-item">\n' +
							'	<span class = "weather-icon"> <img src="./../images/new-weather-forecast-icon/day' + preTextDay.phenomenonaCode + '.png"></span>\n' +
							'	<span class = "weather-text">' + preTextDay.phenomenonatext + '</span>\n' +
							' </li> '
						$('#timeWeatherLisNight').append(timeWeatherListNight)
					}
				}
				//根据24小时相态判断气象
				function getPPhDayPhenomena(pphNumDayArr, cloudNumDayData, preNumDayData) {
					if (pphNumDayArr.every(isSunny)) {
						return iscloudSize(cloudNumDayData)
					} else if (pphNumDayArr.every(isSnowy)) {
						return getPhenomenaCodeByInfo(14)
					} else if (pphNumDayArr.every(isFrozenRain)) {
						return getPhenomenaCodeByInfo(19)
					} else if (pphNumDayArr.some(isRain)) {
						if (pphNumDayArr.some(isSnowy)) {
							return getPhenomenaCodeByInfo(6)
						}
						return isRainSize(preNumDayData)
					}
				}
				//气象数据求和
				function dayDataSum(arr) {
					var s = 0;
					arr.forEach(function (val, idx, arr) {
						s += val;
					}, 0);

					return s;
				};

				// 判断是否是晴天
				function isSunny(element) {
					return (element === 0);
				}
				// 判断是否是雪天
				function isSnowy(element) {
					return (element === 3);
				}
				// 判断是否是雨天
				function isRain(element) {
					return (element === 1);
				}
				// 判断是否是冻雨
				function isFrozenRain(element) {
					return (element === 4);
				}


				//3小时气温图表
				var chart = Highcharts.chart('temperature-charts', {
					chart: {
						type: 'spline'
					},
					title: {
						text: null
					},
					exporting: {
						enabled: false
					},
					credits: {
						enabled: false
					},
					xAxis: {
						visible: false
					},
					yAxis: {
						visible: false
					},
					tooltip: {
						headerFormat: '',
						pointFormat: '温度：{point.y}°C',
						shared: true
					},
					plotOptions: {
						line: {
							dataLabels: {
								enabled: true,
								padding: 5
							},
							enableMouseTracking: true
						}
					},
					series: [{
						type: 'spline',
						name: '气温',
						data: temNumArr,
						showInLegend: false,
						dataLabels: {
							enabled: true,
							format: '{y} °'
						}
					}]
				});
				//24小时气温图表
				var chart = Highcharts.chart('temperature-charts-24hour', {
					chart: {
						type: 'line',
						backgroundColor: 'rgba(0,0,0,0)', //背景色透明

					},
					credits: {
						enabled: false
					},
					title: {
						text: ''
					},
					tooltip: {
						headerFormat: '',
					},
					xAxis: {
						visible: false,
						categories: ''
					},
					yAxis: {
						visible: false
					},
					plotOptions: {
						series: {
							type: 'spline',
							dataLabels: {
								enabled: true,
								format: '{y} °'
							}
						}
					},

					legend: {
						enabled: false
					},
					exporting: {
						enabled: false
					},
					series: [{
						name: "日最高温",
						data: tmaxNumArr,
						color: '#eb6247',
						dataLabels: {
							verticalAlign: 'bottom'
						}
					}, {
						name: "日最低温",
						data: tminNumArr,
						color: '#72a2f1',
						dataLabels: {
							verticalAlign: 'top'
						}
					}]
				});
				//之前图表
				$('#temChartBox').highcharts({
					chart: {},
					title: {
						text: ' '
					},
					xAxis: {
						categories: xAixsTime
					},
					yAxis: [{
						title: {
							text: ' '
						},
						lineWidth: 1,
					}, {
						title: {
							text: ' '
						},
						lineWidth: 1,
						opposite: true
					}],
					legend: {
						padding: 0,
						margin: 6,
						align: 'left',
						verticalAlign: 'top',
						itemDistance: 4,
						itemHiddenStyle: {
							color: '#ccc'
						}
					},
					scrollbar: {
						enabled: false
					},
					plotOptions: {
						series: {
							dataLabels: {
								enabled: false,
								color: 'red'
							}
						}
					},
					series: [{
						type: 'line',
						name: '温度',
						data: temNumArr,
						color: '#e44050'
					}, {
						type: 'column',
						name: '降水',
						data: preNumArr,
						yAxis: 0,
						color: '#92eb92'
					}, {
						type: 'line',
						name: '风速',
						data: windSpeedNumArr,
						color: '#252627'
					}],
					tooltip: {
						shared: true
					},
					exporting: {
						enabled: false
					},
					credits: {
						enabled: false
					}
				})

				$('#humidityChartBox').highcharts({
					chart: {},
					title: {
						text: ' '
					},
					xAxis: {
						categories: xAixsTime
					},
					yAxis: [{
						tickPositions: [0, 50, 100],
						title: {
							text: ''
						}
					}, {
						tickPositions: [0, 50, 100],
						title: {
							text: ''
						},
						opposite: true
					}],
					legend: {
						padding: 0,
						margin: 6,
						align: 'left',
						verticalAlign: 'top',
						itemDistance: 4,
						itemHiddenStyle: {
							color: '#ccc'
						}
					},
					scrollbar: {
						enabled: false
					},
					plotOptions: {
						series: {
							dataLabels: {
								enabled: false,
								color: 'red'
							}
						}
					},
					series: [{
						type: 'line',
						name: '湿度',
						data: rhuNumArr,
						color: '#1ca7ef'
					}, {
						type: 'column',
						name: '云量',
						data: cloudNumArr,
						yAxis: 1,
						color: '#fca04f'
					}],
					tooltip: {
						shared: true
					},
					exporting: {
						enabled: false
					},
					credits: {
						enabled: false
					}
				})

				var _curIdx = $('.data-swiper .swiper-slide-active').data('idx')
				var _curParams = $('.gird-list-item-link-active').siblings(".gird-list-item-option-box").find("input:checked").data("params")
				var pointPopup = ''
				if (_curParams && ([5, 6, 8, 9].indexOf(_curParams) !== -1)) {
					pointPopup = '24小时暂不支持查看详情'
					popup.setHTML(pointPopup)
				} else {
					var pre = preArr[_curIdx]
					// 计算24小时累计降水
					if ($('#weatherRange').val() === '3') {
						pre = preArr.slice(_curIdx * 8, 8 - (8 - (_curIdx + 1) * 8)).reduce(function(prev, curr, idx, arr){
							return Number(prev) + Number(curr)
						})
					}

					var value = ''
					switch ($('#weatherRange').val()) {
						case '0':
						case '3':
							value = Number(pre).toFixed(1) + 'mm'
							break
						case '4':
							value = temArr[_curIdx] + '℃'
							break
						case '5':
							value = tmaxArr[_curIdx] + '℃'
							break
						case '6':
							value = tminArr[_curIdx] + '℃'
							break
						case '7':
							value = rhuArr[_curIdx] + '%'
							break
						case '8':
							value = erhaArr[_curIdx] + '%'
							break
						case '9':
							value = erhiArr[_curIdx] + '%'
							break
						case '10':
							value = windDirectionArr[_curIdx] + '° ' + windSpeedArr[_curIdx] + 'm/s'
							break
						case '11':
							value = cloudArr[_curIdx] + '%'
							break
					}

					pointPopup = [
						'<div class="custom-popup">',
						'<div class="popup-row"><span class="popup-title">地点：</span>' + res.province + ' ' + res.city + ' ' + res.district + '</div>',
						'<div class="popup-row"><span class="popup-title">起报时间：</span>' + $('#reportingTime .time').text() + '</div>',
						'<div class="popup-row"><span class="popup-title">预报时间：</span>' + $('.times .swiper-slide').eq(swiper.activeIndex).html().replace('<br>', ' ') + '</div>',
						'<div class="popup-row"><span class="popup-title">' + $('#weatherRange option:selected').text() + '：</span>' + value + '</div>',
						'<div class="popup-row" style="color: #989494"><span class="popup-title">提示：</span>点击图标隐藏/显示气泡和预报面板</div>',
						'</div>'
					]
					popup.setHTML(pointPopup.join(''))
				}
			})

			setTimeout(function () {
				var zoom = map.getZoom()
				var feature = {
					center: {
						lng: point[0],
						lat: point[1]
					},
					zoom: zoom > 9 ? zoom : 9
				}

				map.flyTo(feature)
				window.singleMarker && (window.singleMarker.remove(), window.singleMarker = null)
				// window.singlePopup && window.singlePopup.remove()

				// window.singlePopup = new mapboxgl.Popup({ offset: 25 })
				// 	.setText('Construction on the Washington Monument began in 1848.')
				window.singleMarker = new mapboxgl.Marker()
					.setLngLat(feature.center)
					.setPopup(popup)
					.addTo(map)
					.togglePopup()
			}, 500)
			localStorage.girddingData = null
		})
	}

	// 色标图切换
	$("#rain-legend-box").click(function() {
		$("#rain-legend").toggle()
	})

	// 加载数据
	var activeTime
	var swiper
	function loadData(param) {
		var type = param || 3
		ajax('/forecastMonitor/gridForecast/gridForecastStainMap.do', {
			param: type
		}, function (res) {
			if (res.body.total === 0) {
				return mui.alert("暂无数据！", "提示")
			}

			// 显示起报时间
			$(".times .time").text(res.body.props.startTime.substring(0, res.body.props.startTime.length - 3))
			$('.times').show()
			map.getSource('spotGeoJSON').setData(res.body.data[0].jsonPath)
			loadPointFeatures(res.body.data[0].pointPath)

			// 处理时间轴条目
			var items = [].concat(res.body.data).reverse().reduce(function (arr, item, idx) {
				return ['<div class="swiper-slide" data-idx="' + (res.body.data.length - 1 - idx) + '">' + dayjs(item.datetime).format('YYYY-MM-DD<br>HH:mm') + '</div>'].concat(arr)
			}, Array(3).fill('<div class="swiper-slide none"></div>'))
			$('.times  .swiper-wrapper').html(items)

			// 生成时间轴控件
			swiper && swiper.destroy()
			swiper = new Swiper('.times .swiper-container', {
				autoplay: {
					delay: 1000,
					stopOnLastSlide: true
				},
				slidesPerView: 'auto',
				slideToClickedSlide: true,
				on: {
					slideChange: function () {
						map.getSource('spotGeoJSON').setData(res.body.data[this.activeIndex].jsonPath)
						loadPointFeatures(res.body.data[this.activeIndex].pointPath)
						window.singleMarker && (window.singleMarker.remove(), window.singleMarker = null)
					},
					autoplayStop: function () {
						$('#play').data("val", 0)
						$('#play').css("background-image", "url(../images/play.png)")
					}
				}
			})
			swiper.autoplay.stop()
			weatSwiper([3, 5, 6, 8, 9].indexOf(Number(type)) > -1 ? 1 : 0)
		})
	}

	/**
	 * 加载 Grid Point GeoJSON
	 * @param {Json文件地址} src 
	 * @param {处理完成后的回调方法} cb 
	 */
	function loadPointFeatures(src, cb) {
		$.getJSON(src, function (data) {
			function copy(features, num) {
				var news = []
				features.forEach(function (feature) {
					news.push($.extend({}, feature, {
						geometry: {
							type: "Point",
							coordinates: [feature.geometry.coordinates[0], toFixedNumber(feature.geometry.coordinates[1] + num)]
						}
					}))
				})

				return news
			}

			function toFixedNumber(number) {
				return Number(Number(number).toFixed(2))
			}

			// 复制数据行，使得116*116的网格数据变为120*120，用于优化层级渲染
			var startRow = [].concat(data.features).slice(0, 116),
				start = [].concat(copy(startRow, -0.1)).concat(copy(startRow, -0.05)),
				endRow = [].concat(data.features).slice(data.features.length - 116, data.features.length),
				end = [].concat(copy(endRow, 0.05)).concat(copy(endRow, 0.1))

			var features = []
				;[].concat(start).concat(data.features).concat(end).forEach(function (feature, index) {
					if (index % 116 === 0) {
						features.push($.extend({}, feature, {
							geometry: {
								type: "Point",
								coordinates: [toFixedNumber(feature.geometry.coordinates[0] - 0.05), feature.geometry.coordinates[1]]
							}
						}))
						features.push(feature)
					} else if ((index + 1) % 116 === 0) {
						features.push(feature)
						features.push($.extend({}, feature, {
							geometry: {
								type: "Point",
								coordinates: [toFixedNumber(feature.geometry.coordinates[0] + 0.05), feature.geometry.coordinates[1]]
							}
						}))
						features.push($.extend({}, feature, {
							geometry: {
								type: "Point",
								coordinates: [toFixedNumber(feature.geometry.coordinates[0] + 0.1), feature.geometry.coordinates[1]]
							}
						}))
						features.push($.extend({}, feature, {
							geometry: {
								type: "Point",
								coordinates: [toFixedNumber(feature.geometry.coordinates[0] + 0.15), feature.geometry.coordinates[1]]
							}
						}))
					} else {
						features.push(feature)
					}
				})

			window.grids = []
			var row = []

			features.forEach(function (feature, index) {
				row.push(feature)

				if ((index + 1) % 120 === 0) {
					window.grids.push(row)
					row = []
				}
			})

			map.getSource('pointGeoJSON').setData({
				"type": "FeatureCollection",
				"features": filterFeatures(currentFilterStep)
			})

			cb && cb()
		})
	}

	/**
	 * 过滤Point
	 * @param {过滤间隔} step 
	 */
	function filterFeatures(step) {
		var isAll = step <= 1

		var features = [].concat(window.grids).map(function (row, ri) {
			if (isAll || (ri != 0 && ri % Number(step / 2) === 0)) {
				return row.filter(function (cell, ci) {
					if (isAll || (ci != 0 && ci % step === 0)) {
						return true
					}

					return false
				})
			}

			return []
		})

		return [].concat.apply([], features)
	}

	// 播放按钮
	$('#play').click(function () {
		if ($(this).data("val") == 0) {
			$(this).data("val", 1)
			$(this).css("background-image", "url(../images/pause.png)")
			swiper && swiper.autoplay.start()
		} else {
			$(this).data("val", 0)
			$(this).css("background-image", "url(../images/play.png)")
			swiper && swiper.autoplay.stop()
		}
	})

	// 色斑图切换
	$('#spotOrText').on('change', function () {
		var type = $('#spotOrText').val()
		if (type == 'spot') {
			map.setLayoutProperty('spotGeoJSON', 'visibility', 'visible')
			map.setLayoutProperty('pointGeoJSON', 'visibility', 'none')
		} else if (type == 'text') {
			map.setLayoutProperty('spotGeoJSON', 'visibility', 'none')
			map.setLayoutProperty('pointGeoJSON', 'visibility', 'visible')
		} else if (type == 'all') {
			map.setLayoutProperty('spotGeoJSON', 'visibility', 'visible')
			map.setLayoutProperty('pointGeoJSON', 'visibility', 'visible')
		}
	})

	// 顶部右侧要素切换
	$("#weatherRange").on("change", function () {
		var param = $("#weatherRange").val()
		var img, name
		switch (param) {
			case '0':
				img = '../images/legend/rain-legend-3h-y.png'
				break
			case '3':
				img = '../images/legend/rain-legend-24h-y.png'
				break
			case '4':
				img = '../images/legend/tem-y.png'
				break
			case '5':
				img = '../images/legend/tem-y.png'
				break
			case '6':
				img = '../images/legend/tem-y.png'
				break
			case '10':
				img = '../images/legend/wind-y.png'
				break
			case '7':
				img = '../images/legend/humidity-y.png'
				break
			case '8':
				img = '../images/legend/humidity-y.png'
				break
			case '9':
				img = '../images/legend/humidity-y.png'
				break
			case '11':
				img = '../images/legend/cloud-y.png'
				break
			default:
				img = name = ''
				break
		}
		$('#typeName .text').html($("#weatherRange option:selected").text())
		$('#rain-legend').attr("src", img)
		loadData(param)
		window.singleMarker && (window.singleMarker.remove(), window.singleMarker = null)
		$("#chart-box").hide()
	})
})

//生成弹出框轮播图
function weatSwiper(index) {
	new Swiper('.chart-container-parent .swiper-container', {
		initialSlide: index || 0,
		observer: true,
		observeParents: true,
		allowTouchMove: false,
		pagination: {
			el: '.pagination-ul',
			clickable: true,
			bulletClass: 'pagination-item',
			bulletActiveClass: 'pagination-item-active',
			renderBullet: function (index, className) {
				return '<li class="' + className + '" data-item="' + index + '" >' + (index === 0 ? 3 : 24) + '小时</li>'
			}
		}
	});
}

// 根据相态获取天气现象
function getPPhPhenomena(pph, cloud, pre) {
	if (pph === 0) {
		return iscloudSize(cloud)
	} else if (pph === 1) {
		return (isRainSize(pre))
	} else if (pph === 2) {
		return getPhenomenaCodeByInfo(6)
	} else if (pph === 3) {
		return getPhenomenaCodeByInfo(14)
	} else if (pph === 4) {
		return getPhenomenaCodeByInfo(19)
	}
}

//根据云量判断多云气象
function iscloudSize(cloud) {

	if (cloud < 30) {
		return getPhenomenaCodeByInfo(0)
	} else if (30 <= cloud && cloud < 70) {
		return getPhenomenaCodeByInfo(1)
	} else if (cloud >= 70) {
		return getPhenomenaCodeByInfo(2)
	}
}
//根据雨量判断多云气象
function isRainSize(pre) {
	if (pre < 10) {
		return getPhenomenaCodeByInfo(7)
	} else if (10 <= pre < 25) {
		return getPhenomenaCodeByInfo(8)
	} else if (25 <= pre < 50) {
		return getPhenomenaCodeByInfo(9)
	} else if (50 <= pre < 100) {
		return getPhenomenaCodeByInfo(10)
	} else if (100 <= pre < 200) {
		return getPhenomenaCodeByInfo(11)
	} else if (pre > 200) {
		return getPhenomenaCodeByInfo(12)
	}

}