$(function () {
	if (!isDebug) {
		var USER_ROLES = ROLES.getUserRoles()
		if (USER_ROLES.indexOf(ROLES.meteorological) === -1) {
			// 检查技术产品查阅权限
			$('#technicalProduct').hide()
		}
	}

	// 城市实况界面预加载是否已经完成
	localStorage.preloaded = '0'
	// 标识城市实况数据是否已经定位并获取完成
	var loaded = false

	mui.plusReady(function () {
		var network = plus.networkinfo.getCurrentType()
		if (network === plus.networkinfo.CONNECTION_NONE || network === plus.networkinfo.CONNECTION_UNKNOW) {
			mui.toast("当前没有网络")
		}

		// 定位获取天气实况信息
		getLocation(undefined, 3);

		//首页返回键处理  
		//处理逻辑：2秒内，连续两次按返回键，则退出应用
		var first = null;
		plus.key.addEventListener('backbutton', function () {
			//首次按键，提示‘再按一次退出应用’  
			if (!first) {
				first = new Date().getTime();
				mui.toast('再按一次退出应用');
				setTimeout(function () {
					first = null;
				}, 2000);
			} else {
				if (new Date().getTime() - first < 2000) {
					plus.runtime.quit();
				}
			}
		}, false);

		// 登录成功后，不会立即跳转到 index.html 需要通知登录页首页已经加载完成，然后由登录页去打开首页，这个控制可以避免登录成功后的短暂白屏情况
		var home = plus.webview.getLaunchWebview()
		mui.fire(home, 'indexLoadComplete')

		// 监听app从后台切换到前台时的事件，刷新首页数据
		var refresh = debounce(function() {
			getEState()
			fetchWeatherInfo()
			latestReport(false)
			severeWeatherEarly(false)
		}, 500)
		document.addEventListener("resume", refresh, false)
		document.addEventListener("foreground", refresh, false)
	})

	// 读取默认的气象服务文件
	var defaultWeatherServeListHtml = localStorage.getItem('weatherServeList')
	if (defaultWeatherServeListHtml) {
		$(".weatherServeList").html(defaultWeatherServeListHtml)
	}

	//index.html  初始化获取当前地理位置并获取当前城市天气实况
	if (!mui.os.plus) {
		showPosition({
			coords: {
				longitude: 113.010965,
				latitude: 28.039426
			}
		})
	}

	var lng, lat;
	function getLocation(success, retry) { //检测是否支持地理定位 如果支持，则运行 getCurrentPosition() 方法。如果不支持，则向用户显示一段消息。
		$(".loction-city-name").text("努力定位中...")
		plus.geolocation.getCurrentPosition(function(position) {
			showPosition(position, success, retry)
		}, showError, {
			enableHighAccuracy: true,
			provider: 'baidu'
		})

		if (navigator.geolocation) { //如果getCurrentPosition()运行成功， //则向参数showPosition中规定的函数返回一个coordinates对象
			// navigator.geolocation.getCurrentPosition(showPosition, showError, { enableHighAccuracy: true });
		} else {
			mui.alert("地理位置不支持!")
			$(".loction-city-name").text("地理位置不支持!");
		}
	}

	function showPosition(position, success, retry) { //showPosition() 函数获得并显示经度和纬度
		lng = position.coords.longitude; //经度
		lat = position.coords.latitude; //纬度
		var url = 'http://restapi.amap.com/v3/geocode/regeo?key=b0dd50868f4a0d1562953dc7f528d062&location=' + lng + ',' + lat;
		$.getJSON(url, function (data) {
			var address = data.regeocode.addressComponent
			var district = (address.district && address.district.length > 0) ? address.district : '无法获取当前位置!'
			var city = (address.city && address.city.length > 0) ? address.city : '无法获取当前位置!'

			localStorage.setItem('firstLocalCityName', district)
			localStorage.setItem('locationLonLat', lng + ',' + lat)
			localStorage.setItem('locationCity', city)
			weatherCity([lng, lat], city); //初始化
			getEState();
			
			if (district === '无法获取当前位置!') {
				if (retry) {
					setTimeout(function() {
						getLocation(success, --retry)
					}, 100)
				} else {
					mui.alert("无法获取当前位置，请尝试开启GPS定位后重新打开APP")
				}
			} else {
				retry = 0
				success && success()
			}

			if (retry === 0) {
				$(".loction-city-name").text(district)
			}
		});
	}

	function showError(error) {
		switch (error.code) {
			case error.PERMISSION_DENIED:
				$(".loction-city-name").text("用户不允许地理定位!")
				break;
			case error.POSITION_UNAVAILABLE:
				$(".loction-city-name").text("无法获取当前位置!")
				break;
			case error.TIMEOUT:
				$(".loction-city-name").text("操作超时!")
				break;
			case error.UNKNOWN_ERROR:
				$(".loction-city-name").text("未知错误")
				break;
			default: {
				var address = localStorage.getItem('firstLocalCityName')
				if (!address) {
					address = '获取当前位置失败'
				} else {
					// 定位失败, 获取上一次定位的天气信息
					weatherCity(localStorage.getItem('locationLonLat').split(','), localStorage.getItem('locationCity'))
				}
				$(".loction-city-name").text(address)
				break;
			}
		}
	}

	//城市实况天气
	function weatherCity(lonLat, city, hasMask) {
		var url = "/home/weatherCity.do";
		var lat = lonLat[1];
		var lon = lonLat[0];
		var params = {
			lat: lat,
			lon: lon,
			stationCode: '',
			city: city
		}
		//		console.log(JSON.stringify(params))
		http.get(url, params, _weatherCitySuccess, true, hasMask);
	}

	function _weatherCitySuccess(data, info) {
		var prevData = JSON.parse(localStorage.getItem('cityData'))
		data = $.extend({}, prevData, data)
		var resData = data.body;
		var CIMISScode, cimissContent, weatherIconUrl;
		if (resData.tem == 999999 || !resData.tem) {
			$(".location-tem").hide();
		} else {
			$(".location-tem").text(resData.tem + '℃');
		}

		resData.aqi = parseInt(resData.aqi)
		var aqi = resData.aqi;
		if (aqi > 0) {
			$("#aqi-option").text("AQI " + resData.aqi).show();
			$(".location-polltion").css('padding', '0.16rem').attr('class', 'location-polltion hide location-polltion-bg' + resData.qualityLevel);
			(data.body).indexQualityLevel = checkAqiLevel(resData.aqi);
		} else {
			$('#aqi-option').hide();
		}
		if (resData.weatherCode != 999999) {
			var weatherCodeInfo = getWeatherCodeByInfo(resData.weatherCode)
			if (weatherCodeInfo) {
				resData.CIMISScode = weatherCodeInfo.weatherCode;
				//晚上换成晚上图标
				weatherIconUrl = '../images/weather-little-icon/weather_' + resData.CIMISScode + '_720_2.png';
				if (resData.CIMISScode === '1002' || resData.CIMISScode === '1008' || resData.CIMISScode === '1011') {
					var t = getHour() + ":" + getMin();
					if ((CompareDate(t, '19:59') && CompareDate(t, '07:59')) || (!CompareDate(t, '19:59') && !CompareDate(t, '07:59'))) {
						weatherIconUrl = '../images/weather-little-icon/weather_' + resData.CIMISScode + '_720_2' + '_night' + '.png';
					}
				}
				(data.body).cimissContent = weatherCodeInfo.cimissContent
			}
		}
		if (resData.stationCode) {
			var indexStationCode = resData.stationCode;
			$(".locational-left-part").attr("data-stationCode", indexStationCode);
			// 不确定下面一行是用来做什么
			// (data.body).indexCityName = getStationByCode(indexStationCode).city;
		}
		if (resData.windSpeed != 999999) {
			var windData = getWindData(resData.windSpeed)
			if (windData) {
				(data.body).indexWindSpeedName = getWindData(resData.windSpeed)[0];
			}
		}

		$(".weather-icon").attr({ src: weatherIconUrl }).show()

		localStorage.setItem('cityData', JSON.stringify(data))
		localStorage.firstLocalFlag = 0;
		loaded = true

		// 预加载天气预报界面
		if (mui.os.plus) {
			var weatherForecast = plus.webview.getWebviewById('weatherForecast')
			if (weatherForecast) {
				mui.fire(weatherForecast, 'refreshLive')
			} else {
				mui.preload({
					id: 'weatherForecast',
					url: '../web/weatherForecast.v3.html'
				})
			}
		}
	}

	//最新气象服务文件  beign  			option: 0首页,1决策 ，2其他
	function latestReport(hasMask) {
		var url = "/home/latestReport.do";
		var token = localStorage.Token;
		var device = JSON.parse(localStorage.device)
		var params = {
			pageNum: 1,
			// fileType: 0,
			token: token,
			option: 0,
			pageSize: 10,
			userId: localStorage.username,
			deviceId: (device && device.deviceId) || 'uuid_123456',
		};
		// ajaxPost(url, params, _lalatestReportSuccess, '');
		ajax(url, params, _lalatestReportSuccess, 'post', hasMask);
	}

	var reports = {}

	function _lalatestReportSuccess(data, info) {
		reports = {}
		if (data.body.total == 0) {
			mui.alert("请等待更新最新服务信息", "提示", function () { });
			return false;
		}
		var weatherServeList = $(".weatherServeList");
		var resDatas = data.body.data;
		var liStr = '',
			resPublishDatetime, PublishDatetimeTxt, weatherImgData = {},
			description;
		for (var i = 0; i < 3; i++) {
			resPublishDatetime = resDatas[i].publishDatetime;
			PublishDatetimeTxt = parseInt(resPublishDatetime.substring(5, 7)) + '月' + resPublishDatetime.substring(8, 10) +
				'日' + resPublishDatetime.substring(11, 13) + '时';
			weatherImgData[('imgUrlArr' + (resDatas[i].fileId))] = resDatas[i].imgUrl;
			reports[resDatas[i].fileId] = resDatas[i]

			if (resDatas[i].description == null) {
				description = resDatas[i].fileName
			} else {
				description = resDatas[i].description
			}

			liStr += '<li class="weatherServeItem" data-category=' + resDatas[i].category + ' data-id="' + resDatas[i]
				.fileId +'"data-filename="' + resDatas[i].fileName + '" data-length="' + (resDatas[i].imgUrl).length + '" >' +
				'<div class="weatherServeLinkBox">' +
				'<span class="signDot ' + ((parseInt(resDatas[i].isRead) == 1) ? 'readDot' : 'unreadDot') + '"></span>' +
				'<a class="weatherServeLink" href="' + resDatas[i].imgUrl + '">' + description + '</a>' +
				'</div>' +
				'<div class="weatherServeTimeBox">' +
				'<time class="weatherServeTime">' + PublishDatetimeTxt + '</time>' +
				'</div>' +
				'</li>';
		}
		weatherServeList.empty().append(liStr);
		localStorage.IndexStorageWeatherImgData = JSON.stringify(weatherImgData);
		localStorage.setItem('weatherServeList', liStr)
	}

	//强天气预警
	function severeWeatherEarly(hasMask) {
		var url = "/home/severeWeatherEarly.do";
		ajax(url, '', _severeWeatherEarlySuccess, 'get', hasMask);
	}

	function _severeWeatherEarlySuccess(data, info) {
		var earlyWarnTxt = $(".earlyWarnTxt");
		if (data.body.total == 0) {
			$('#sereveWarningLink').hide()
			$("#earlyWarningIcon").attr('src', "../images/no-warning.png").addClass('no-warning');
			earlyWarnTxt.text('无预警或预警信号。');
			localStorage.weatherEarlys = '[]'
			refreshWeatherEarly()
			return false;
		}

		$('.mui-content').addClass('warning')
		$('#sereveWarningLink').show()
		var resData = data.body.data;
		var provinceNumArr = [],
			cntyNumArr = [],
			provinceStr = '',
			cntyStr = '',
			j, earlyWarningIconUrl;
		for (var i = 0; i < resData.length; i++) {
			switch (parseInt(resData[i].unitType)) {
				case 1:
					provinceNumArr.push(resData[i]);
					break;
				case 3:
					cntyNumArr.push(resData[i]);
					break;
			}
		}
		if (provinceNumArr.length.length != 0) {
			// 为了提升效率，首页滚动最多展示5条省级预警
			var len = provinceNumArr.length > 5 ? 5 : provinceNumArr.length
			for (j = 0; j < len; j++) {
				earlyWarningIconUrl = "../images/earlyWarningIcon/" + provinceNumArr[j].earlyTypePY + "-" + provinceNumArr[j].earlyLevel +
					".svg";
				provinceStr += '<li class="early-item" data-width="" data-order="' + j + '" data-url="' + earlyWarningIconUrl +
					'">' + provinceNumArr[j].sendContent + '</li>';
			}
		}
		if (cntyNumArr.length != 0) {
			for (var h = 0; h < 1; h++) {
				earlyWarningIconUrl = "../images/earlyWarningIcon/" + cntyNumArr[h].earlyTypePY + "-" + cntyNumArr[h].earlyLevel +
					".svg";
				cntyStr += '<li class="early-item" data-width="" data-order="' + j + '"  data-url="' + earlyWarningIconUrl + '">' +
					cntyNumArr[h].sendContent + '</li>';
			}
		}
		$("#earlyWarnTxtOne").html(provinceStr + cntyStr);
		$("#earlyWarnTxtTwo").html(provinceStr + cntyStr);
		if (provinceNumArr.length != 0) {
			earlyWarningIconUrl = "../images/earlyWarningIcon/" + provinceNumArr[0].earlyTypePY + "-" + provinceNumArr[0].earlyLevel +
				".svg";
			$("#earlyWarningIcon").attr("src", earlyWarningIconUrl).removeClass("no-warning");
		} else {
			if (cntyNumArr.length != 0) {
				earlyWarningIconUrl = "../images/earlyWarningIcon/" + cntyNumArr[0].earlyTypePY + "-" + cntyNumArr[0].earlyLevel +
					".svg";
				$("#earlyWarningIcon").attr("src", earlyWarningIconUrl).removeClass("no-warning");
			}
		}

		initEarlyWarn()
		localStorage.weatherEarlys = JSON.stringify(resData)
		refreshWeatherEarly()
	}

	function refreshWeatherEarly() {
		mui.plusReady(function() {
			var weatherForecast = plus.webview.getWebviewById('weatherForecast')
			if (weatherForecast) {
				mui.fire(weatherForecast, 'refreshWeatherEarly')
			}
		})
	}

	//气象服务文件状态更改：未读→已读   begin 
	function fileRead(dom, activeId,activeFileName) {
		var url = "/home/settingFileFlag.do"
		var id = activeId;
		var device = JSON.parse(localStorage.device)
		var params = {
			userId: localStorage.username,
			deviceId: (device && device.deviceId) || 'uuid_123456',
			fileId: id,
			fileName:activeFileName
		};
		ajax(url, params, function (data) {
			_fileReadSuccess(data, dom)
		})
	}

	//气象服务文件状态更改：未读→已读  end
	function _fileReadSuccess(data, info) {
		var $this = info;
		$this.find(".signDot").removeClass("unreadDot").addClass("readDot");
	}

	// 监听刷新文件服务
	window.addEventListener('refreshLatestReport', function () {
		latestReport()
	})

	// 监听刷新应急响应
	window.addEventListener('refreshEmergencyStatus', function () {
		getEState()
	})

	//应急状态查询
	function getEState() {
		// var url = "/home/checkEmergencyStatus.do";
		var url = "/findUsefulEmergency.go";
		var params = {};
		http.post(url, params, _getEStateSuccess, true, false);
	}

	function _getEStateSuccess(data, info) {
		if (data.body != null && data.body.length !==0) {
			var resDatas = data.body;
			
			function getEStateData(data){
				var obj = {}
				//缓存数据和添加清空方法
				Object.defineProperty(obj, "init", {
					value: function(key){
						var _cityArr = ['长沙','株洲','湘潭','岳阳','衡阳','郴州','永州','邵阳','娄底','常德','张家界','怀化','湘西州','益阳']
						_cityArr.forEach(function(val,idx){
							obj[val]={}
						})
						return this;
					},
					enumerable: false
				});
				Object.defineProperty(obj, "set", {
					value: function(val){
						for(v in this){
								this[v] = val;
						}
						return this;
					},
					enumerable: false
				});
				obj.init()
				var areaObj={ALL:'全省',CS:'长沙',ZZ:'株洲',XT:'湘潭',YUEY:'岳阳',HY:'衡阳',CZ:'郴州',YZ:'永州',SY:'邵阳',LD:'娄底',CD:'常德',ZJJ:'张家界',HH:'怀化',XXZ:'湘西州',YIY:'益阳'}
				for(i=resDatas.length-1;i>=0;i--){
				// for(i=0;i<=resDatas.length-1;i++){
					var resArr =  resDatas[i].locations.split(',')
					resArr.forEach(function(val,idx){
						if(val.indexOf("ALL")==-1){
							obj[areaObj[val]]=resDatas[i]
						}else{
							obj.set(resDatas[i])
						}
					})
				}
				
				if(localStorage.locationCity){
					var _curCity = localStorage.locationCity
					var _curCityStr = _curCity.substring(0,_curCity.length-1)
					if(obj[_curCityStr].emLevel){
						var _strObj = codeQuery(obj[_curCityStr].type, obj[_curCityStr].emLevel)
						$(".index-title").text("湖南省气象局" + "（" + _strObj.levelText + "）");
						$(".index-bar-nav").css("background-image", "url(" + _strObj.src + ")");
					}else{
						$(".index-bar-nav").css("background-image", "");
						$(".index-title").text("湖南省气象台");
					}
				}
			}
			getEStateData(data)
		}else{
			$(".index-bar-nav").css("background-image", "");
			$(".index-title").text("湖南省气象台");
		}
	}

	function codeQuery(type, level) {
		var emergencyState = [{
			value: 1,
			text: '暴雨',
			src: "../images/emergencyState/nav-by.jpg",
			emergencyLevel: [{
				value: 1,
				level: 'Ⅰ',
				src: "dd"
			}, {
				value: 2,
				level: 'Ⅱ',
				src: "dd"
			}, {
				value: 3,
				level: 'Ⅲ',
				src: "dd"
			}, {
				value: 4,
				level: 'Ⅳ',
				src: "dd"
			}]
		}, {
			value: 2,
			text: '暴雪',
			src: "../images/emergencyState/nav-bx.jpg",
			emergencyLevel: [{
				value: 1,
				level: 'Ⅰ',
				src: "dd"
			}, {
				value: 2,
				level: 'Ⅱ',
				src: "dd"
			}, {
				value: 3,
				level: 'Ⅲ',
				src: "dd"
			}, {
				value: 4,
				level: 'Ⅳ',
				src: "dd"
			}]
		}, {
			value: 4,
			text: '低温雨雪冰冻',
			src: "../images/emergencyState/nav-bd.jpg",
			emergencyLevel: [{
				value: 1,
				level: 'Ⅰ',
				src: "dd"
			},{
				value: 2,
				level: 'Ⅱ',
				src: "dd"
			}, {
				value: 3,
				level: 'Ⅲ',
				src: "dd"
			}, {
				value: 4,
				level: 'Ⅳ',
				src: "dd"
			}]
		}, {
			value: 5,
			text: '高温',
			src: "../images/emergencyState/nav-gw.jpg",
			emergencyLevel: [{
				value: 1,
				level: 'Ⅰ',
				src: "dd"
			},{
				value: 2,
				level: 'Ⅱ',
				src: "dd"
			}, {
				value: 3,
				level: 'Ⅲ',
				src: "dd"
			}, {
				value: 4,
				level: 'Ⅳ',
				src: "dd"
			}]
		}, {
			value: 6,
			text: '干旱',
			src: "../images/emergencyState/nav-gh.jpg",
			emergencyLevel: [{
				value: 1,
				level: 'Ⅰ',
				src: "dd"
			}, {
				value: 2,
				level: 'Ⅱ',
				src: "dd"
			}, {
				value: 3,
				level: 'Ⅲ',
				src: "dd"
			}, {
				value: 4,
				level: 'Ⅳ',
				src: "dd"
			}]
		}];
		var obj = {};
		emergencyState.forEach(function (item) {
			if (item.value == type) {
				obj.typeText = item.text;
				obj.src = item.src;
				item.emergencyLevel.forEach(function (item) {
					if (item.value == level) {
						obj.levelText = item.level;
					}
				})
			}
		});
		return obj;
	}

	//	init   begin
	severeWeatherEarly();
	latestReport();

	mui(".weatherServeList").on('click', '.weatherServeItem', function () {
		var activeFileId = $(this).attr("data-id");
		var activeFileName = $(this).attr("data-filename");
		console.log(activeFileName)
		var activeFileImgLength = $(this).attr("data-length");
		if (Number(activeFileImgLength) == 0) {
			mui.alert("该文件已损坏!", "提示", "确定", function () { })
			return false
		}
		var category = $(this).data('category');
		if ($(this).find(".signDot").hasClass("unreadDot")) {
			fileRead($(this), activeFileId, activeFileName);
		}
		localStorage.activefiactiveFileIdleId = activeFileId;
		localStorage.indexActiveFileImgLength = activeFileImgLength;
		localStorage.category = category;
		mui.openWindow({
			url: '../web/servingProductsImg.html',
			extras: {
				name: 'indexSkip',
				info: reports[activeFileId]
			},
			styles: {
				statusbar: {
					background: localStorage.statusbarColor
				}
			}
		});
	});

	mui("#weatherServeAllBox").on('tap', '#wetherServeViewAll', function () {
		mui.openWindow({
			url: '../web/servingProducts.v3.html',
			styles: {
				statusbar: {
					background: localStorage.statusbarColor
				}
			}
		});
	});
	mui(".index-bar-nav").on('tap', '#settingBtn', function (e) {
		e.stopPropagation()
		mui.openWindow({
			url: '../web/setting.html'
		});
	});
	//页面跳转
	mui(".sceneNav").on('tap', '.girddingSceneNavItem', function () {
		mui.openWindow({
			url: '../web/griddingForecast.v3.html'
		});
	});

	mui("#monSceneBox").on('tap', '.typhoon-secneNavItem', function () {
		mui.openWindow({
			url: '../web/typhoon.v3.html'
		})
	});

	mui("#monSceneBox").on('tap', '#rainfallScene', function () {
		mui.openWindow({
			url: '../web/monitoringOfLive/newMap.v3.mapbox.html'
		})
	});
	mui("#monSceneBox").on('tap', '#temScene', function () {
		mui.openWindow({
			url: '../web/monitoringOfLive/new-tem.v3.mapbox.html'
		})
	});
	mui("#monSceneBox").on('tap', '#severeWeatherScene', function () {
		mui.openWindow({
			url: '../web/monitoringOfLive/new-severe-weather.v3.html'
		})
	});
	mui("#monSceneBox").on('tap', '#raderScene', function () {
		mui.openWindow({
			url: '../web/monitoringOfLive/radar.html'
		})
	});
	mui("#monSceneBox").on('tap', '#satelliteScene', function () {
		mui.openWindow({
			url: '../web/monitoringOfLive/satellite.html'
		})
	});
	mui("#monSceneBox").on('tap', '#envirScene', function () {
		mui.openWindow({
			url: '../web/monitoringOfLive/new-environmentalMonitoring.v3.html'
		});
	});
	mui("#technicalProductSceneBox").on('tap', '#meetSceneNavItem', function () {
		mui.openWindow({
			url: '../web/technicalProducts/meet.v3.html'
		})
	});
	mui("#technicalProductSceneBox").on('tap', '#decadSceneNavItem', function () {
		mui.openWindow({
			url: '../web/technicalProducts/new-decad.v3.html'
		});
	});
	mui("#monSceneBox").on('tap', '#waterSceneNavItem', function () {
		mui.openWindow({
			url: '../web/monitoringOfLive/waterRegimenMap.v3.html'
		});
	});
	mui("#wrapper").on('tap', '#sereveWarningLink', function () {
		mui.openWindow({
			url: '../web/new-severeWeatherWarning.v3.mapbox.html'
		});
	});
	mui("#technicalProductSceneBox").on('tap', '#patternSceneNavItem', function () {
		mui.openWindow({
			url: '../web/technicalProducts/pattern.html'
		})
	});
	mui("#forecastInfoNavBox").on('tap', '#rainfallFiSceneNavItem', function () {
		mui.openWindow({
			url: '../web/forecastInfo/rainfallInfo.html'
		});
	});
	mui("#forecastInfoNavBox").on('tap', '#temFiSceneNavItem', function () {
		mui.openWindow({
			url: '../web/forecastInfo/temInfo.html'
		});
	});
	mui("#forecastInfoNavBox").on('tap', '#severeWeatherFiSceneNavItem', function () {
		mui.openWindow({
			url: '../web/forecastInfo/new-severeWeather.v3.html'
		});
	});
	mui("#forecastInfoNavBox").on('tap', '#arealRainSceneNavItem', function () {
		mui.openWindow({
			url: '../web/forecastInfo/arealRainfall.html',
			styles: {
				statusbar: {
					background: localStorage.statusbarColor
				}
			}
		});
	});

	mui("#technicalProductSceneBox").on('tap', '#situationSceneNavItem', function () {
		mui.openWindow({
			url: '../web/monitoringOfLive/situationOfDisaster_sub.v3.html'
		});
	});
	mui("#forecastInfoNavBox").on('tap', '#envirForecastSceneNavItem', function () {
		mui.openWindow({
			url: '../web/forecastInfo/new-envirForecast.v3.html'
		});
	});

	mui(".sceneNav").on('tap', '.untappedSceneNavItem', function () {
		mui.alert('该功能正在开发！', '提示', function () { });
	});

	mui("#wrapper").on("tap", "#locationalWrap", function () {
		// 检查是否处于定位状态
		if ($(".loction-city-name").text() === '努力定位中...') {
			return
		}

		function callback() {
			// 检查定位所在的城市天气实况数据是否已经存储完成
			if (!loaded) {
				return
			}

			if (mui.os.plus) {
				var weatherForecast = plus.webview.getWebviewById('weatherForecast')
				if (weatherForecast) {
					// 检查城市实况界面是否已经加载完成过一次
					if (localStorage.preloaded === '0') {
						return
					}

					mui.fire(weatherForecast, 'refresh')
				}
			}
	
			mui.openWindow({
				id: 'weatherForecast',
				url: '../web/weatherForecast.v3.html'
			})
		}

		var texts = ['无法获取当前位置!', '获取当前位置失败', '未知错误', '操作超时!', '无法获取当前位置!', '用户不允许地理定位!']
		if (texts.indexOf($(".loction-city-name").text()) > -1) {
			getLocation(callback, 3)
		} else {
			callback()
		}
	});
	//TODO  test 
	mui("#technicalProductSceneBox").on('tap', '#testBtn', function () {
		/* mui.openWindow({
			url: '../web/testDemo/slider-default.html',
			styles: {
				statusbar: {
					background: '#4f8eff'
				}
			}
		}); */
	});
	mui("#technicalProductSceneBox").on('tap', '#mapTestBtn', function () {
		mui.openWindow({
			url: '../web/testDemo/NEW-ClipImg.html',
			styles: {
				statusbar: {
					background: localStorage.statusbarColor
				}
			}
		});
	});

	mui("#technicalProductSceneBox").on('tap', '#pdfjs', function () {
		mui.openWindow({
			url: '../web/pdf/index.html',
			styles: {
				statusbar: {
					background: localStorage.statusbarColor
				}
			}
		});
	});

	$('.mui-title').click(function() {
		if ($(this).text() != '湖南省气象台') {
			mui.openWindow({
				url: '../web/emergencyStateMap.mapbox.html'
			})
		}
	})

	// mui("#forecastInfoNavBox").on('tap', '#test', function() {
	// 	mui.openWindow({
	// 		url: '../web/emergencyStateAdd.html',
	// 		styles: {
	// 			statusbar: {
	// 				background: '#4f8eff'
	// 			},
	// 			hardwareAccelerated: false
	// 		}
	// 	});
	// });
	var ws; //websocket实例
	var lockReconnect = false; //避免重复连接
	var wsUrl = HOST.replace('http', 'ws') + '/ws/' + localStorage.Token;

	function createWebSocket(url) {
		try {
			ws = new WebSocket(url);
			initEventHandle();
		} catch (e) {
			reconnect(url);
		}
	}

	function initEventHandle() {
		ws.onclose = function () {
			reconnect(wsUrl);
		};
		ws.onerror = function () {
			reconnect(wsUrl);
		};
		ws.onopen = function () {
			//心跳检测重置
			heartCheck.reset().start();

			if (isDebug) {
				console.log('open: ' + wsUrl)
			}
		};
		ws.onmessage = function (event) {
			// 如果获取到消息，心跳检测重置
			// 拿到任何消息都说明当前连接是正常的
			heartCheck.reset().start();

			//			console.log(event.data)
			var message = event.data
			if (message !== 'HeartBeat') {
				var data = JSON.parse(message)
				if (data.key === 'file') {
					// 更新气象服务文件
					latestReport(false)
				} else if (data.key === 'waring') {
					// 更新强天气预警信号
					_severeWeatherEarlySuccess(JSON.parse(data.value))
				} else if (data.key === 'weather') {
					// 更新天气实况
					fetchWeatherInfo()
				} else if (data.key === 'emergency') {
					// 更新应急响应状态
					_getEStateSuccess(JSON.parse(data.value))
					// getEState()
				}
			}
		}
	}

	function reconnect(url) {
		if (lockReconnect) return;
		lockReconnect = true;
		//没连接上会一直重连，设置延迟避免请求过多
		setTimeout(function () {
			createWebSocket(url);
			lockReconnect = false;
		}, 3000);
	}

	//心跳检测
	var heartCheck = {
		timeout: 10000, //10秒
		timeoutObj: null,
		serverTimeoutObj: null,
		reset: function () {
			clearTimeout(this.timeoutObj);
			clearTimeout(this.serverTimeoutObj);
			return this;
		},
		start: function () {
			var self = this;
			this.timeoutObj = setTimeout(function () {
				try {
					//这里发送一个心跳，后端收到后，返回一个心跳消息，
					//onmessage拿到返回的心跳就说明连接正常
					ws.send("HeartBeat");
				} catch (e) {}
				self.serverTimeoutObj = setTimeout(function () { //如果超过一定时间还没重置，说明后端主动断开了
					try {
						ws.close(); //如果onclose会执行reconnect，我们执行ws.close()就行了.如果直接执行reconnect 会触发onclose导致重连两次
					} catch (e) {}
				}, self.timeout)
			}, this.timeout)
		}
	}

	createWebSocket(wsUrl);

	$(window).on('unload', function () {
		try {
			ws.close()
		} catch (e) {}
	})

	function fetchWeatherInfo() {
		var latLon = localStorage.getItem('locationLonLat')

		if (latLon) {
			var latlngs = latLon.split(',')
			http.get('/home/weatherCity.do', {
				lat: latlngs[1],
				lon: latlngs[0],
				stationCode: '',
				city: localStorage.getItem('locationCity'),
				time: Date.now()
			}, function (res) {
				_weatherCitySuccess(res)
			}, true, false)
		}
	}
});
