$(function () {
	// 初始化容器宽高
	$(".mui-content").height($(window).height() - $('header').css('height').replace('px', ''))
	
	mui.init({
		swipeBack: false, //启用右滑关闭功能
		gestureConfig: {
			tap: true, //默认为true
			doubletap: true, //默认为false
			longtap: true, //默认为false
			swipe: true, //默认为true
			drag: false, //默认为true
			hold: false, //默认为false，不监听
			release: false //默认为false，不监听
		}
	})

	// 初始化地图
	var map = GIS.init()
	map.addControl(new mapboxgl.AttributionControl({
		compact: true,
		customAttribution: '湖南省环境监测中心站'
	}), 'bottom-left')
	
	map.on('load', function () {
		GIS.utils.addBlankGeoJSONSource('geojson-point')

		map.addLayer({
			id: 'geojson-text',
			source: 'geojson-point',
			type: "symbol",
			layout: {
				"text-size": 14,
				"text-field": "{text}",
				"text-font": ["Microsoft YaHei"],
				"text-allow-overlap": false,
				"text-ignore-placement": false
			},
			paint: {
				"text-halo-width": 10,
				"text-halo-color": {
					"type": "identity",
					"property": "color"
				},
				"text-color": {
					"type": "identity",
					"property": "text-color"
				}
			}
		})

		// 图标需要单独构建一个图层
		map.addLayer({
			id: 'geojson-icon',
			source: 'geojson-point',
			type: "symbol",
			layout: {
				"visibility": "none",
				"icon-size": 0.4,
				"icon-image": "{icon}",
				"icon-allow-overlap": true,
				"icon-ignore-placement": true
			}
		})

		loadData()
	})

	// 点击事件
	var popup
	map.on('click', 'geojson-icon', pointClickEvent)
	map.on('click', 'geojson-text', pointClickEvent)
	function pointClickEvent(e) {
		var feature = e.features[0]
		popup = new mapboxgl.Popup()
            .setLngLat(feature.geometry.coordinates)
            .setHTML(feature.properties.popup)
			.addTo(map)
			
		// 缓存一些数据用于图表页面的数据查询
		localStorage.envirRankStationCode = feature.properties.stationCode
		localStorage.envirRankStationName = feature.properties.stationName
		localStorage.envirActiveSort = $('.datehour-option.datehour-option-active').data('legend') === 'a' ? 0 : 1
	}

	// 切换图层数据源
	function changeMapSource() {
		popup && popup.remove()
		var classify = $('.datehour-option.datehour-option-active').data('classify')
		var type = $('.datehour-option.datehour-option-active').data('type')
		$('#envirRealTime').text(dayjs(page.times[classify]).format('MM月DD日HH时'))
		map.getSource('geojson-point').setData(page[classify][type])
	}

	/**
	 * 加载数据
	 */
	var page = { times: {} }
	var iconKeys = ['haze', 'fog']
	function loadData() {
		var classify = $('.datehour-option.datehour-option-active').data('classify')
		if (page[classify] && page[classify].startTime === page.times[classify]) {
			changeMapSource()
			return
		}

		var url = classify == 1 ? '/environment/weather/weatherParam.do' : '/air/airQuality.do'
		ajax(url, {
			datetime: page.times[classify] || ''
		}, function (res) {
			var features = {}, keys, time
			if (classify == 1) {
				time = localStorage.weatherStartTime = localStorage.airAualityTime = res.body.datetime

				// 缓存最新数据时间
				if (!$('#nextTimeBtn').data('time' + classify)) {
					$('#nextTimeBtn').data('time' + classify, time)
				}

				keys = ['haze', 'fog', 'vis', 'rhu', 'winSAvg10mi'].map(function (item) {
					features[item] = []
					return item
				})

				res.body.data.forEach(function (item) {
					keys.forEach(function (key) {
						var isIcon = iconKeys.indexOf(key) != -1
						var val = key === 'vis' ? item[key] / 1000 : item[key]

						// 过滤空数据
						if ((!isIcon && item[key] === null) || (isIcon && item[key + 'Level'] === null)) {
							return
						}

						var popup = [
							'<div class="custom-popup">',
							'<div class="popup-row"><span class="popup-title">站名：</span>' + item.city + ' ' + (item.cnty === 'null' ? '' : item.cnty) + '</div>',
							'<div class="popup-row"><span class="popup-title">时间：</span>' + dayjs(time).format('MM月DD日HH时') + '</div>',
							'<div class="popup-row"><span class="popup-title">' + $('.ele-datehour-option[data-type=' + key + ']').html() + '：</span>' + (isIcon ? texts[key](item[key + 'Level']) : val) + '</div>',
							isIcon ? '<div class="popup-row"><span class="popup-title">能见度：</span>' + (item.vis / 1000) + '</div><div class="popup-row"><span class="popup-title">相对湿度：</span>' + item.rhu + '%</div>' : '',
							isIcon ? '' : '<div class="popup-row"><span class="popup-title">查看图表：</span><span class="popup-chart-icon"></span></div>',
							'</div>'
						]

						features[key].push({
							"type": "Feature",
							"geometry": {
								"type": "Point",
								"coordinates": [Number(item.lon), Number(item.lat)]
							},
							"properties": $.extend({
								stationName: item.city + ' ' + item.cnty,
								stationCode: item.stationCode,
								popup: popup.join('')
							}, isIcon ? {
								icon: key + '-' + item[key + 'Level']
							} : {
								text: val,
								color: colors[key](val),
								'text-color': key === 'winSAvg10mi' ? '#fff' : '#000'
							})
						})
					})
				})
			} else {
				time = localStorage.envirStartTime = dayjs(res.body.data.datetimeNew).format('YYYY-MM-DD HH:mm:ss')
				
				// 缓存最新数据时间
				if (!$('#nextTimeBtn').data('time' + classify)) {
					$('#nextTimeBtn').data('time' + classify, time)
				}

				keys = ['aqi', 'pm25', 'pm10', 'o3'].map(function (item) {
					features[item] = []
					return item
				})

				res.body.data.data.forEach(function (item) {
					var station = getStationByStationCode(item.stationCode)
					keys.forEach(function (key) {
						// 过滤空数据
						if (item[key] === null) {
							return
						}

						var popup = [
							'<div class="custom-popup">',
							'<div class="popup-row"><span class="popup-title">站名：</span>' + station.ename + ' ' + station.siteName + '</div>',
							'<div class="popup-row"><span class="popup-title">时间：</span>' + dayjs(item.dateTime).format('MM月DD日HH时') + '</div>',
							'<div class="popup-row"><span class="popup-title">' + $('.ele-datehour-option[data-type=' + key + ']').html() + '：</span>' + item[key] + '</div>',
							key === 'aqi' ? '<div class="popup-row"><span class="popup-title">首要污染物：</span>' + texts.pollutants(item.primaryPollutant) + '</div>' : '',
							'<div class="popup-row"><span class="popup-title">查看图表：</span><span class="popup-chart-icon"></span></div>',
							'</div>'
						]

						features[key].push({
							"type": "Feature",
							"geometry": {
								"type": "Point",
								"coordinates": [Number(station.lon), Number(station.lat)]
							},
							"properties": {
								text: item[key],
								color: colors.aqi(key === 'aqi' ? item.aqi : iaqi[key](item[key])),
								popup: popup.join(''),
								stationName: station.ename + ' ' + station.siteName,
								stationCode: station.stationCode,
								'text-color': '#fff'
							}
						})
					})
				})
			}

			page.times[classify] = time || page.times[classify]
			page[classify] = { startTime: time }

			for (var temptype in features) {
				page[classify][temptype] = {
					type: "FeatureCollection",
					features: features[temptype]
				}
			}

			changeMapSource()
		})
	}

	var colors = {
		vis: function (val) {
			var colors = ['#fff', '#c9edfd', '#8ee0f8', '#7bfc30', '#fffd00', '#ffb446', '#ff5500', '#fe0002', '#9603ff', '#712700']

			if (val >= 30) {
				return colors[0]
			} else if (val >= 20 && val < 30) {
				return colors[1]
			} else if (val >= 10 && val < 20) {
				return colors[2]
			} else if (val >= 5 && val < 10) {
				return colors[3]
			} else if (val >= 3 && val < 5) {
				return colors[4]
			} else if (val >= 2 && val < 3) {
				return colors[5]
			} else if (val >= 1 && val < 2) {
				return colors[6]
			} else if (val >= 0.5 && val < 1) {
				return colors[7]
			} else if (val >= 0.2 && val < 0.5) {
				return colors[8]
			} else if (val >= 0 && val < 0.2) {
				return colors[9]
			}
		},
		rhu: function (val) {
			var colors = ['#00bfff', '#00ff00', '#40ff00', '#a5ff00', '#ffff00', '#ff8300', '#ff0000', '#f74602', '#f702b5', '#f116af', '#000']

			if (val == 100) {
				return colors[0]
			} else if (val >= 90 && val < 100) {
				return colors[1]
			} else if (val >= 80 && val < 90) {
				return colors[2]
			} else if (val >= 70 && val < 80) {
				return colors[3]
			} else if (val >= 60 && val < 70) {
				return colors[4]
			} else if (val >= 50 && val < 60) {
				return colors[5]
			} else if (val >= 40 && val < 50) {
				return colors[6]
			} else if (val >= 30 && val < 40) {
				return colors[7]
			} else if (val >= 20 && val < 30) {
				return colors[8]
			} else if (val >= 10 && val < 20) {
				return colors[9]
			} else if (val >= 0 && val < 10) {
				return colors[8]
			}
		},
		winSAvg10mi: function (val) {
			var colors = ['#a5ff00', '#68d14e', '#4ec166', '#40a1b5', '#4268c5', '#5056b9', '#544eb1', '#52468d']

			if (val == 12) {
				return colors[0]
			} else if (val >= 10 && val < 12) {
				return colors[1]
			} else if (val >= 8 && val < 10) {
				return colors[2]
			} else if (val >= 6 && val < 8) {
				return colors[3]
			} else if (val >= 4 && val < 6) {
				return colors[4]
			} else if (val >= 2 && val < 4) {
				return colors[5]
			} else if (val >= 1 && val < 2) {
				return colors[6]
			} else if (val >= 0 && val < 1) {
				return colors[7]
			}
		},
		aqi: function(aqi) {
			var colors = ['#6ec128', '#dfcb3a', '#fb5e28', '#e50424', '#851054', '#3e0856']
		
			if (aqi < 51) {
				return colors[0]
			} else if (aqi >= 51 && aqi <= 100) {
				return colors[1]
			} else if (aqi >= 101 && aqi <= 150) {
				return colors[2]
			} else if (aqi >= 151 && aqi <= 200) {
				return colors[3]
			} else if (aqi >= 201 && aqi <= 300) {
				return colors[4]
			} else if (aqi > 300) {
				return colors[5]
			} else {
				return '#FFFFFF'
			}
		}
	}

	var iaqi = {
		pm25: function(val) {
			if (val < 35) {
				return 50 * (val - 0) / 35 + 0
			} else if (val < 75) {
				return 50 * (val - 35) / 40 + 50
			} else if (val < 115) {
				return 50 * (val - 75) / 40 + 100
			} else if (val < 150) {
				return 50 * (val - 115) / 35 + 150
			} else if (val < 250) {
				return 100 * (val - 150) / 100 + 200
			} else if (val < 350) {
				return 100 * (val - 250) / 100 + 300
			} else if (val < 500) {
				return 100 * (val - 350) / 150 + 400
			} else {
				return 100 * (500 - 350) / 150 + 400
			}
		},
		pm10: function(val) {
			if (val < 50) {
				return 50 * (val - 0) / 50 + 0
			} else if (val < 150) {
				return 50 * (val - 50) / 100 + 50
			} else if (val < 250) {
				return 50 * (val - 150) / 100 + 100
			} else if (val < 350) {
				return 50 * (val - 250) / 100 + 150
			} else if (val < 420) {
				return 100 * (val - 350) / 70 + 200
			} else if (val < 500) {
				return 100 * (val - 420) / 80 + 300
			} else if (val < 600) {
				return 100 * (val - 500) / 100 + 400
			} else {
				return 100 * (600 - 500) / 150 + 400
			}
		},
		o3: function(val) {
			if (val < 160) {
				return 50 * (val - 0) / 160 + 0
			} else if (val < 200) {
				return 50 * (val - 160) / 40 + 50
			} else if (val < 300) {
				return 50 * (val - 200) / 100 + 100
			} else if (val < 400) {
				return 50 * (val - 300) / 100 + 150
			} else if (val < 800) {
				return 100 * (val - 400) / 400 + 200
			} else if (val < 1000) {
				return 100 * (val - 800) / 200 + 400
			} else if (val < 1200) {
				return 100 * (val - 1000) / 200 + 400
			} else {
				return 100 * (1200 - 1000) / 200 + 400
			}
		}
	}

	var texts = {
		haze: function(level) {
			if (level == 1) {
				return '轻度霾'
			} else if (level == 2) {
				return '中度霾'
			} else if (level == 3) {
				return '重度霾'
			} else {
				return '无'
			}
		},
		fog: function(level) {
			if (level == 1) {
				return '雾'
			} else if (level == 2) {
				return '大雾'
			} else if (level == 3) {
				return '浓雾'
			} else if (level == 4) {
				return '强浓雾'
			} else {
				return '无'
			}
		},
		pollutants: function(val) {
			if (val) {
				return val
					.replace(/PM(\d+\.?\d+)/, 'PM<sub>$1</sub>')
					.replace(/O(\d+)/, 'O<sub>$1</sub>')
			}

			return '无'
		}
	}

	// 图表点击事件
	$('#map').on('click', '.popup-row', function() {
		if ($(this).find('.popup-chart-icon').length === 0) {
			return
		}

		mui.openWindow({
			url:'../../web/monitoringOfLive/environmental-chart.html',
			id: localStorage.envirRankStationCode,
			waiting: {
				autoShow: false
			},
			extras:{
				name: localStorage.envirRankStationName,
				stationCode: localStorage.envirRankStationCode
			},
			styles: {
				statusbar: {
					background: localStorage.statusbarColor
				}
			}
		})
	})

	// 要素切换
	$('#envirOptionWrapper .ele-datehour-option').click(function () {
		var type = $(this).data('type')
		var legend = $(this).data('legend')
		var classify = $(this).data('classify')

		if (classify == 0) {
			$('.mapboxgl-ctrl-attrib').show()
		} else {
			$('.mapboxgl-ctrl-attrib').hide()
		}

		$('#envirOptionWrapper .ele-datehour-option').removeClass("datehour-option-active")
		$(this).addClass("datehour-option-active")
		$("#envir-legend").attr("src", '../../images/monitoringOfLive/envir-' + legend + '.png')

		if (iconKeys.indexOf(type) != -1) {
			map.setLayoutProperty('geojson-text', 'visibility', 'none')
			map.setLayoutProperty('geojson-icon', 'visibility', 'visible')
		} else {
			map.setLayoutProperty('geojson-icon', 'visibility', 'none')
			map.setLayoutProperty('geojson-text', 'visibility', 'visible')
		}

		loadData()
	})

	// 排位
	$('#environmental-rank-link').click(function() {
		// 缓存一些数据，用于排位界面使用
		var type = $(".ele-datehour-option.datehour-option-active").data("type")
		localStorage.activeEleType = iconKeys.indexOf(type) != -1 ? 'vis' : type
		localStorage.activeEleClassify = $(".ele-datehour-option.datehour-option-active").data("classify")

		mui.openWindow({
		    url:'../../web/monitoringOfLive/environmental-rank.html',
			styles: {
				statusbar: {
					background: localStorage.statusbarColor
				}
			}
		})
	})

	// 下一个时次
	$('#nextTimeBtn').click(function() {
		var classify = $('.ele-datehour-option.datehour-option-active').data('classify')
		var maxTime = $(this).data('time' + classify)
		var nextTime = dayjs(page.times[classify]).add(1, 'hour')

		if (maxTime && dayjs(maxTime).isBefore(nextTime)) {
			mui.alert('已是最新数据！')
			return
		}

		page.times[classify] = dayjs(page.times[classify]).add(1, 'hour').format('YYYY-MM-DD HH:mm:ss')
		loadData()
	})
	
	// 上一个时次
	$('#prevTimeBtn').click(function() {
		var classify = $('.ele-datehour-option.datehour-option-active').data('classify')
		page.times[classify] = dayjs(page.times[classify]).add(-1, 'hour').format('YYYY-MM-DD HH:mm:ss')
		loadData()
	})

	// 切换图标
	$("#envir-conent").on("click", "#environmental-legend-box", function(e) {
		$("#envir-legend").attr("src", '../../images/monitoringOfLive/envir-' + $(".ele-datehour-option.datehour-option-active").data('legend') + '.png').toggle()
		//防止点击到翻页按钮
		e.stopPropagation()
	})
})