$(function () {
	mui.init({
		swipeBack: false, //启用右滑关闭功能
		gestureConfig: {
			tap: true, //默认为true
			doubletap: true, //默认为false
			longtap: true, //默认为false
			swipe: true, //默认为true
			drag: false, //默认为true
			hold: false, //默认为false，不监听
			release: false //默认为false，不监听
		}
	})

	// 初始化容器宽高
	var scr_h = $(window).height()
	$(".mui-content").height(scr_h - $('header').css('height').replace('px', ''))

	// 初始化地图
	var map = GIS.init()
	map.addControl(new mapboxgl.AttributionControl({
		compact: true,
		customAttribution: '湖南水文网'
	}), 'bottom-left')

	map.on('load', function () {
		GIS.utils.addBlankGeoJSONSource('geojson-point')

		map.addLayer({
			id: 'geojson-text',
			source: 'geojson-point',
			type: "symbol",
			layout: {
				"text-field": "{value}",
				"text-size": 14,
				"text-offset": [0, 1.2],
				"text-font": ["Microsoft YaHei"],
				"icon-image": {
					"type": "identity",
					"property": "pointType"
				},
				"icon-anchor": 'top',
				"icon-size": 0.4,
			},
			paint: {
				"text-halo-width": 2,
				"text-halo-color": "#fff",
				"text-color": {
					"type": "identity",
					"property": "color"
				},
			}
		})
		loadData(true)
	})

	// 点击事件
	var popup
	map.on('click', 'geojson-text', function (e) {
		var feature = e.features[0]
		popup = new mapboxgl.Popup()
			.setLngLat(feature.geometry.coordinates)
			.setHTML(feature.properties.popup)
			.addTo(map)
	})

	/**
	 * 加载数据
	 */
	var page = {
		uncertain: {
			checked: true,
			count: 0,
			color: '#777777',
			pointType: 'point.uncertain'
		},
		alarm: {
			checked: true,
			count: 0,
			color: '#dd524d',
			pointType: 'point.alarm'
		},
		normal: {
			checked: true,
			count: 0,
			color: '#4cd964',
			pointType: 'point.normal'
		}
	}
	var cacheTime = ''
	function loadData(notButton) {
		var params = {
			dataType: $('#rain-datehour-ul li.datehour-option-active').data('val'),
			basin: $('#basinSel option:selected').val(),
			datetime: $('#temShowRealtime').data('time') || ''
		}

		ajax('/water/waterRegimen/getData.do', params, function (res) {
			var datetime = dayjs(res.body.datetime)
			$('#temShowRealtime').data('time', datetime.format('YYYY-MM-DD HH:00:00')).html(datetime.format('MM月DD日HH时'))
			var _nowTime = dayjs().format('YYYY-MM-DD HH:mm:ss')
			if (notButton) {
				cacheTime = $('#temShowRealtime').data('time') || _nowTime;
			}
			page.normal.count = page.uncertain.count = page.alarm.count = 0
			page.normal.checked = page.uncertain.checked = page.alarm.checked = true
			$('.item').removeClass('cancel')

			var features = []
			res.body.data.forEach(function (item) {
				if (!item.lat || !item.lon) {
					return
				}
			
				// 计算状态、数量、颜色
				var pointType,color
				var value = Number((item.waterLevel ? item.waterLevel : item.reservoirWaterLevel ? item.reservoirWaterLevel.replace(',', '') : 0))
				var highestWaterLevelRecords = Number(item.highestWaterLevelRecords || 0)
				var threshold = Number(item.warningWaterLevel ? item.warningWaterLevel : item.floodControlLevel ? item.floodControlLevel.replace(',', '') : 0)
				if (value === 0 || threshold === 0) {
					pointType = page.uncertain.pointType
					color = page.uncertain.color
					page.uncertain.count += 1
					return false
				} else if (value > threshold) {
					pointType = page.alarm.pointType
					color = page.alarm.color
					page.alarm.count += 1
				} else {
					pointType = page.normal.pointType
					color = page.normal.color
					page.normal.count += 1
				}
				var popup = GIS.utils.createDefaultStylePopupHtml({
					'河名': item.riverName,
					'站名': item.stationName,
					'当前水位': value,
					[(params.dataType == 2 ? '汛限' : '警戒') + '水位']: threshold,
					'历史最高水位': highestWaterLevelRecords
				})

				features.push({
					"type": "Feature",
					"geometry": {
						"type": "Point",
						"coordinates": [Number(item.lon), Number(item.lat)]
					},
					"properties": {
						popup: popup,
						value: value,
						pointType: pointType,
						color: color
					}
				})
			})

			popup && popup.remove()
			map.setFilter('geojson-text', null)
			map.getSource('geojson-point').setData({
				type: "FeatureCollection",
				features: features
			})
			for (var key in page) {
				$('#' + key).html(page[key].count)
			}

			// 缓存选中的相关条件，当切换到列表页面时自动同步
			localStorage.waterActiveTime = datetime.format('YYYY-MM-DD HH:00:00')
			localStorage.waterActiveType = params.dataType
			localStorage.waterActiveBasin = params.basin
		})
	}

	// 切换水域
	$('#basinSel').change(function () {
		$("#basinSelTxt").text($(this).find("option:selected").text())
		loadData()
	})

	// 日期选择
	var dtPicker = new mui.DtPicker({
		type: 'hour',
		"beginDate": new Date(2018,10,01),
		"endDate": new Date()
	})
	$("#showInfoBox").click(function () {
		var _curDate = $('#temShowRealtime').data('time')
		dtPicker.setSelectedValue(_curDate)
		dtPicker.show(function (items) {
			var datetime = items.text + ':00:00'
			$('#temShowRealtime').html(dayjs(datetime).format('MM月DD日HH时')).data('time', datetime)
			loadData()
		})
	})

	// 切换为列表
	$('.navigation').click(function () {
		mui.openWindow({
			url: 'waterRegimen.html',
			styles: {
				statusbar: {
					background: localStorage.statusbarColor
				}
			}
		})
	})

	// 选项切换
	$('.mapBottom .item').click(function () {
		popup && popup.remove()
		var id = $(this)[0].id
		$(this).toggleClass('cancel')
		page[id].checked = !page[id].checked

		var filters = ['in', 'color']
		for (var key in page) {
			if (page[key].checked) {
				filters.push(page[key].color)
			}
		}
		map.setFilter('geojson-text', filters)
	})

	// 切换类型
	$('#rain-datehour-ul').on('tap', 'li', function () {
		var text = $(this).text()
		if (text === '河流水情日报表') {
			$('#basinSelBox').show()
		} else {
			$('#basinSelBox').hide()
		}

		$(this).addClass('datehour-option-active').siblings().removeClass('datehour-option-active')
		loadData()
	})

	$("#prevTimeBtn").on("tap", function () {
		var _endTime = dayjs($('#temShowRealtime').data('time')).subtract(1, 'hour')
		console.log($('#temShowRealtime').data('time'), cacheTime)
		$('#temShowRealtime').html(_endTime.format('MM月DD日HH时')).data('time', _endTime.format('YYYY-MM-DD HH:mm:ss'))
		loadData()
	});
	$("#nextTimeBtn").on("tap", function () {
		var _endTime = dayjs($('#temShowRealtime').data('time')).add(1, 'hour')
		console.log($('#temShowRealtime').data('time'), cacheTime)
		var _firstTime = dayjs(cacheTime)
		if (_endTime > _firstTime) {
			mui.alert("已是最新数据！")
		} else {
			$('#temShowRealtime').html(_endTime.format('MM月DD日HH时')).data('time', _endTime.format('YYYY-MM-DD HH:mm:ss'))
			loadData()
		}
	});
	// 色标图切换
	$("#warnningContent").on("tap", "#rain-legend-box", function (e) {
		$("#legend").toggle()
		//防止点击到翻页按钮
		e.stopPropagation()
	});
})