//		var w = 1200;
//		var h = 1800;
//		var minLon = 108;
//		var maxLon = 114;
//		var minLat = 28;
//		var maxLat = 32;
//		var stationInterval = 0.05;

function GeoMapUtil() {
	var
		w, //图片宽
		h, //图片高
		minLon,
		maxLon,
		minLat,
		maxLat,
		stationInterval, //格距
		xGridLength, //X轴，单个格距的像素长度
		yGridLength, //Y轴，单个格距的像素长度
		xInterval, //X轴向一像素与经度换算
		yInterval; //Y轴
	var areas, lonStationCount, latStationCount;

	//canvas绘制对象
	var context;

	/**
	 * 初始化
	 */
	this.init = function(_minLon, _maxLon, _minLat, _maxLat, _interval, _w, _h) {
		this.w = _w;
		this.h = _h;
		this.minLat = _minLat;
		this.maxLat = _maxLat;
		this.minLon = _minLon;
		this.maxLon = _maxLon;
		this.stationInterval = _interval;
		this.initGeoMap();
		this.xGridLength = accDiv(this.w, this.lonStationCount);
		this.yGridLength = accDiv(this.h, this.latStationCount);
	}

	this.initGeoMap = function() {
		//计算X轴向的像素与经纬度秒数换算
		//一度=60分;一分=60秒； accMul(
		this.xInterval = accDiv(Subtr(this.maxLon, this.minLon), this.w);
		//计算Y轴向的像素与经纬度换算
		this.yInterval = accDiv(Subtr(this.maxLat, this.minLat), this.h);

		/**地理编码，以预设格距对地理区间进行编码**/
		//计算经向格点数,X轴
		this.lonStationCount = accDivForInt(Subtr(this.maxLon, this.minLon), this.stationInterval);
		//计算纬向格点数，Y轴
		this.latStationCount = accDivForInt(Subtr(this.maxLat, this.minLat), this.stationInterval);
		//总格数
		var stationCount = accMul(this.lonStationCount, this.latStationCount);

		//声明地理区间的二维数组
		this.areas = new Array();
		for (var i = 0; i < stationCount; i++) {
			this.areas[i] = new Array();
			//计算分割索引
			var latIdx = parseInt(i / (this.lonStationCount)) + 1;
			var lonIdx = i % (this.lonStationCount) + 1;
			//生成索引代码
			var areaCode = this.encodeGridForLonLatIndex(lonIdx, latIdx);

			this.areas[i][0] = areaCode;
			//格点容器，数据存储器
			this.areas[i][1] = new Array();
			//X坐标
			this.areas[i][2] = Math.round(accDiv(accMul(lonIdx, this.stationInterval), this.xInterval));
			//Y坐标
			this.areas[i][3] = Math.round(accDiv(accMul(latIdx, this.stationInterval), this.yInterval));
			/*//XY平方和(开方后为半径),用于搜寻计算*/
			this.areas[i][4] = accSUMQuares(this.areas[i][2], this.areas[i][3]);
			 
		}
	}

	 

	/**
	 * 注册控件对象
	 * data:控件数据，可以是对象
	 * lon
	 * lat
	 * @param radius 控件作用半径，单位像素
	 */
	this.registerElement = function(data, lon, lat, radius) {

		//计算编码
		var lonDiff = Subtr(lon, this.minLon);
		//Y轴反向
		var latDiff = Subtr(this.maxLat ,lat);
		var lonIdx = accDivForInt(lonDiff, this.stationInterval);
		var latIdx = accDivForInt(latDiff, this.stationInterval) - 1;
		//计算格点数组索引
		var idx = (latIdx) * this.lonStationCount + lonIdx;
		//构建控件数据单元
		var conItem = new Array;
		//相对屏幕的X坐标
		conItem[0] = Math.round(accDiv(lonDiff, this.xInterval));
		//相对屏幕的Y坐标
		conItem[1] = Math.round(accDiv(latDiff, this.yInterval));
		//XY平方和(开方后为半径),用于搜寻计算
		conItem[2] = accSUMQuares(conItem[0], conItem[1]);
		//数据
		conItem[3] = data;
		//控件作用半径
		conItem[4] = radius;
		//注册对象到格点对象集
		if(idx < 0){
			idx = 0;
		}
		if(idx >= this.areas.length){
			idx = this.areas.length - 1;
		}
		this.areas[idx][1].push(conItem);

		//console.log(conItem);
		//		console.log(" reg idx="+idx+" lonIdx:"+lonIdx+" latIdx:"+latIdx);
//		console.log("======注册地图内置对象Begin");
//		console.log("  REG:data=" + data);
//		console.log("  REG:lon=" + lon + " lat=" + lat);
//		console.log("  REG:idx=" + idx + " lonIdx:" + lonIdx + " latIdx:" + latIdx);
//		console.log("  REG:x=" + conItem[0] + " y=" + conItem[1]);
//		console.log("======End");

		return conItem;
	}
	
	
	/**
	 * 注册控件对象
	 * data:控件数据，可以是对象
	 * lon
	 * lat
	 * @param radius 控件作用半径，单位像素
	 */
	this.registerElementMax = function(data, lon, lat, radius,tScale) {

		//计算编码
		var lonDiff = Subtr(lon, this.minLon);
		//Y轴反向
		var latDiff = Subtr(this.maxLat ,lat);
		var lonIdx = accDivForInt(lonDiff, this.stationInterval);
		var latIdx = accDivForInt(latDiff, this.stationInterval) - 1;
		//计算格点数组索引
		var idx = (latIdx) * this.lonStationCount + lonIdx;
		//构建控件数据单元
		var conItem = new Array;
		//相对屏幕的X坐标
		conItem[0] = Math.round(accDiv(lonDiff, this.xInterval));
		//相对屏幕的Y坐标
		conItem[1] = Math.round(accDiv(latDiff, this.yInterval));
		//同步放大
		conItem[0] = Math.round(tScale * conItem[0]); 
		conItem[1] = Math.round(tScale * conItem[1]); 
		//XY平方和(开方后为半径),用于搜寻计算
		conItem[2] = accSUMQuares(conItem[0], conItem[1]);
		//数据
		conItem[3] = data;
		//控件作用半径
		conItem[4] = radius;
		//注册对象到格点对象集
		if(idx < 0){
			idx = 0;
		}
		if(idx >= this.areas.length){
			idx = this.areas.length - 1;
		}
		this.areas[idx][1].push(conItem);
//		console.log("======注册地图内置对象Begin");
//		console.log("  REG:data=" + data);
//		console.log("  REG:lon=" + lon + " lat=" + lat);
//		console.log("  REG:idx=" + idx + " lonIdx:" + lonIdx + " latIdx:" + latIdx);
//		console.log("  REG:x=" + conItem[0] + " y=" + conItem[1]);
//		console.log("======End");
//		 
		return conItem;
	}
	
	//清除注册数据
	this.clear=function(){
		for(var i = 0;i<this.areas.length;i++){
			this.areas[i][1].length = 0;
		}
	}
	
	/**
	 * 根据XY坐标搜索控件，并判断是否触发点击事件
	 */
	this.getElementDataByXY = function(x, y) {

		//计算索引
		var x_idx = parseInt(x / this.xGridLength);
		var y_idx = parseInt(y / this.yGridLength);

		//取出周围九格
		var gridList = [];
		for (var i = -2; i < 1; i++) {
			var _x_idx = x_idx + i;
			for (var j = -1; j < 2; j++) {
				var _y_idx = y_idx + j;
				if (_x_idx > -1 && _y_idx > -1) {
					var idx = _y_idx * this.lonStationCount + _x_idx;
					gridList.push(this.areas[idx + 1]);
					
				}
			}
		}
//		console.log(gridList)
		//取出控件对象
		var controllObjItems = new Array();
		
		if(gridList.length > 0){
			for (var i = 0; i < gridList.length; i++) {
				//优化格点索引引发的计算错误，最后一位格点数据为Null,下标越界.
				if(gridList[i] == null) {
					continue;
				}
				var item = gridList[i][1];
				if (item == null || item.length == 0) {
					continue;
				} else {
					for (var j = 0; j < item.length; j++) {
						controllObjItems.push(item[j]);
					}
				}
			}
		}
		//搜索  
		var nearObject;
		var distance = 1000000; //距离
		for (var i = 0; i < controllObjItems.length; i++) {
			//遍历比较距离
			var newDistance = getXYDistance(x, y, controllObjItems[i][0], controllObjItems[i][1]);
//			console.log("搜索第"+i+"次:"+controllObjItems[i][3]+" ->"+newDistance+" distance="+distance);
			if (newDistance <= distance) {
				distance = newDistance;
				nearObject = controllObjItems[i];
			}
			//A 第一次注册 郴州点 点击 距离  = 10 
			//B 第二次注册 郴州店 点击 距离 =10 
			//搜索到A点 newDistance = 10
			//与B点比较 newDistance < 条件不成立
			//函数输出 A点
			
			
			//检查控件作用半径，距离超出不处理
			if (nearObject != null && distance > nearObject[4]) {
				nearObject = null;
			}
		}
		//输出
		return nearObject;
	}

	//根据经纬度查询坐标
	this.getXYFromLonLat = function(lonIdx, latIdx) {
		//保留小数点后两位
		var x = ((lat - map_lat_start) * map_lat_px).toFixed(2);
		var y = ((lon - map_lon_start) * map_lon_px).toFixed(2);
		return [x, y];
	}

	//格点经纬度编码 编码格式(总计08位） 
	//(经度-起始经度)/格点间距<4位>+(纬度-起始纬度度)/格点间距<4位>
	this.encodeGridForLonLatIndex = function(lonIdx, latIdx) {
		lonIdx = lonIdx - 1;
		latIdx = latIdx - 1;
		var encodeStr = (10000 + lonIdx).toString().substr(1, 4);
		encodeStr = encodeStr + (10000 + latIdx).toString().substr(1, 4);
		return encodeStr;
	}

	//根据经纬度与格距计算编码
	this.encodeGridForLonLat = function(lon, lat) {
		var lonDiff = Subtr(lon, this.minLon);
		var latDiff = Subtr(lat, this.minLat);
		var lonIdx = accDivForInt(lonDiff, this.stationInterval);
		var latIdx = accDivForInt(latDiff, this.stationInterval);
		return this.encodeGridForLonLatIndex(lonIdx, latIdx);
	}

	//根据XY相对像素计算对应的经纬度
	this.calcLonLatByXY = function(x, y){
		var sumLon = this.maxLon - this.minLon;
		var sumLat = this.maxLat - this.minLat;
		var avgLon = accDiv(sumLon, this.w);
		var avgLat = accDiv(sumLat, this.h);
		var returnObj = {};
		returnObj.lon = accAdd(this.minLon, accMul(avgLon, x));
		returnObj.lat = accAdd(this.minLat, accMul(avgLat, y));
		return returnObj;
	}

	//根据经纬度计算对应的相对像素
	this.calcXYByLonLat = function(lon, lat){
		var sumLon = this.maxLon - this.minLon;
		var sumLat = this.maxLat - this.minLat;
		var avgLon = accDiv(sumLon, this.w);
		var avgLat = accDiv(sumLat, this.h);
		var returnObj = {};
		returnObj.x = accDiv(Subtr(lon, this.minLon), avgLon);
		returnObj.y = accDiv(Subtr(lat, this.minLat), avgLat);
		return returnObj;
	}

	//获取坐标距离
	function getXYDistance(x1, y1, x2, y2) {
		var calX = x1 - x2;
		var calY = y1 - y2;
		return Math.pow(accSUMQuares(calX, calY), 0.5);
	}

	//求平方和
	function accSUMQuares(arg1, arg2) {
		return Math.round(accAdd(accMul(arg1, arg1), accMul(arg2, arg2)));
	}
}

//js 加法计算  
//调用：accAdd(arg1,arg2)  
//返回值：arg1加arg2的精确结果   
function accAdd(arg1, arg2) {
	var r1, r2, m;
	try {
		r1 = arg1.toString().split(".")[1].length
	} catch (e) {
		r1 = 0
	}
	try {
		r2 = arg2.toString().split(".")[1].length
	} catch (e) {
		r2 = 0
	}
	m = Math.pow(10, Math.max(r1, r2))
	return ((arg1 * m + arg2 * m) / m).toFixed(2);
}

/**
 * js 减法计算 
 * @param {Object} arg1
 * @param {Object} arg2
 */
function Subtr(arg1, arg2) {
	var r1, r2, m, n;
	try {
		r1 = arg1.toString().split(".")[1].length
	} catch (e) {
		r1 = 0
	}
	try {
		r2 = arg2.toString().split(".")[1].length
	} catch (e) {
		r2 = 0
	}
	m = Math.pow(10, Math.max(r1, r2));
	//last modify by deeka  
	//动态控制精度长度  
	n = (r1 >= r2) ? r1 : r2;
	return ((arg1 * m - arg2 * m) / m).toFixed(2);
}
//js 除法函数  
//调用：accDiv(arg1,arg2)  
//返回值：arg1除以arg2的精确结果   
function accDiv(arg1, arg2) {
	var t1 = 0,
		t2 = 0,
		r1, r2;
	try {
		t1 = arg1.toString().split(".")[1].length;
	} catch (e) {}
	try {
		t2 = arg2.toString().split(".")[1].length;
	} catch (e) {}
	with(Math) {
		r1 = Number(arg1.toString().replace(".", ""));
		r2 = Number(arg2.toString().replace(".", ""));
		return (r1 / r2) * pow(10, t2 - t1);
	}
}

//js 除法函数
//调用：accDiv(arg1,arg2)  
//返回值：arg1除以arg2的整数结果（四舍五入）
function accDivForInt(arg1, arg2) {
	return Math.round(accDiv(arg1, arg2));
}

//js 乘法函数  
//调用：accMul(arg1,arg2)   
//返回值：arg1乘以arg2的精确结果   
function accMul(arg1, arg2) {
	var m = 0,
		s1 = arg1.toString(),
		s2 = arg2.toString();
	try {
		m += s1.split(".")[1].length
	} catch (e) {}
	try {
		m += s2.split(".")[1].length
	} catch (e) {}
	return Number(s1.replace(".", "")) * Number(s2.replace(".", "")) / Math.pow(10, m)
}
