var Utils = {
	contain: function(lng, lat) {
		if (lng >= 108.65 && lng <= 114.4 && lat >= 24.5 && lat <= 30.25) {
			return true
		}
		return false
	},
	randomColor: function(val) {
		return '#' + (val === 0 ? 'ffffff' : Math.floor(Math.random() * 0xffffff).toString(16))
	},
	/**
	 * 地理/逆地理编码
	 * @param query 地名或经纬度
	 */
	geocoderSearch: function(query, cb) {
		if (!query) {
			return cb && cb(undefined)
		}

		var rgeoURL = 'https://restapi.amap.com/v3/geocode/regeo?output=json&radius=50&extensions=all&key=' + GIS.amapKey + '&location='
		var geoURL = 'https://restapi.amap.com/v3/place/text?types=&city=&children=&offset=1&page=1&extensions=all&key=' + GIS.amapKey + '&keywords='

		var matches = query.match(/^[ ]*(?:Lat: )?(-?\d+\.?\d*)[, ]+(?:Lng: )?(-?\d+\.?\d*)[ ]*$/i)
		var url = (matches ? rgeoURL : geoURL) + query

		$.ajax({
			url: url,
			dataType: 'json',
			success: function(res) {
				var info = matches ? res.regeocode.addressComponent : (res.pois.length > 0 ? {
					province: res.pois[0].pname,
					city: res.pois[0].cityname,
					district: res.pois[0].adname,
					location: res.pois[0].location
				} : undefined)
				
				var result = info ? (info.location ? info : (info.location = query, info)) : undefined
				cb && cb(result && result.province === '湖南省' ? result : undefined)
			},
			error: function() {
				mui.toast("查询失败，网络异常...")
			}
		})
	},
	toPonitTitleGeoJSON: function(data, name) {
		return data.map(function(v) {
			return {
				"type": "Feature",
				"geometry": {
					"type": "Point",
					"coordinates": [Number(v.lon), Number(v.lat)]
				},
				"properties": {
					"title": v[name].replace('气象站', '').replace('水利站', '').replace('水管站', '').replace(/^(.*)站$/, '$1'),
					"offset": v.offset || [0, 0]
				}
			}
		})
	},
	createDefaultTextLayerOptions: function(id, features, options) {
		return $.extend(true, {
			"id": id,
			"type": "symbol",
			"source": {
				"type": "geojson",
				"data": {
					"type": "FeatureCollection",
					"features": features
				}
			},
			"layout": {
				"text-size": 13,
				"text-field": "{title}",
				"text-font": ["Microsoft YaHei"],
			},
			"paint": {
				"text-halo-width": 1,
				"text-halo-color": "#fff",
				"text-color": "#444",
			}
		}, options || {})
	},
	createDefaultStylePopupHtml: function(map, station) {
		var htmls = ['<div class="custom-popup">']

		if ($.isPlainObject(station)) {
			htmls.push('<div class="popup-row"><span class="popup-title">站号：</span>' + station.stationCode + '</div>')
			htmls.push('<div class="popup-row"><span class="popup-title">站名：</span>' + station.city + ' ' + station.cnty + ' ' + station.name + '</div>')
		}

		if ($.isPlainObject(map)) {
			for (var key in map) {
				htmls.push('<div class="popup-row"><span class="popup-title">' + key + '：</span>' + map[key] + '</div>')
			}
		}

		htmls.push('</div>')
		return htmls.join('')
	},
	addBlankImageSource: function(name) {
		if (GIS.map) {
			GIS.map.addSource(name || 'default-image-source', {
				"type": "image",
				"url": GIS.defaults.blankImageURI,
				"coordinates": [
					[108.65, 30.25],
					[114.4, 30.25],
					[114.4, 24.5],
					[108.65, 24.5]
				]
			})
		}
	},
	addBlankGeoJSONSource: function(name) {
		if (GIS.map) {
			GIS.map.addSource(name || 'default-geojson-source', {
				"type": "geojson",
				"data": {
					"type": "FeatureCollection",
					"features": []
				}
			})
		}
	},
	forcedRenderMap: function() {
		if (GIS.map) {
			GIS.map.setPitch(0)
		}
	},
	hexToGba: function(hex) {
		return {
			red: parseInt("0x" + hex.slice(1, 3)),
			green: parseInt("0x" + hex.slice(3, 5)),
			blue: parseInt("0x" + hex.slice(5, 7))
		}
	}
}

var GeoJSON = {
	city: {
		name: 'city',
		json: Utils.toPonitTitleGeoJSON(cityData, 'city')
	},
	cnty: {
		name: 'cnty',
		json: Utils.toPonitTitleGeoJSON(cntyData, 'cnty')
	},
	station: {
		name: 'station',
		json: Utils.toPonitTitleGeoJSON(townsStationData, 'name')
	},
	mock: {
		name: 'mock',
		json: cntyData.map(function(v) {
			var val = parseInt(Math.random() * 100)
			var color = Utils.randomColor()
			return {
				"type": "Feature",
				"geometry": {
					"type": "Point",
					"coordinates": [Number(v.lon), Number(v.lat)]
				},
				"properties": {
					"title": v.cnty,
					"value": val,
					"color": color
				}
			}
		})
	}
}

function init(options) {
	if (!mapboxgl.supported()) {
		mui.alert('您的系统版本不支持硬件加速，无法使用地图服务...')
		return
	}

	mui.showLoading && mui.showLoading()

	mapboxgl.accessToken = 'pk.eyJ1IjoiaWZ6bSIsImEiOiJjamswc3M1a2gwYWEwM3Zxa3ZsMjh3djkwIn0.h93-XtdRdtoC1KbVv_ZIow'
	options = $.extend({
		// 是否需要动态绘制色斑
		spot: false,
	}, {
		dragRotate: false,
		pitchWithRotate: false,
		preserveDrawingBuffer: true,
		// 不同源的冲突碰撞检测
		crossSourceCollisions: false,

		container: 'map',
		center: [111.56215, 27.42757],
		zoom: 5.5,
		minZoom: 5,
		maxZoom: 20,
		maxBounds: [
			[104.94, 20.89],
			[118.03, 33.52]
		],
		style: {
			"version": 8,
			"sources": {
				"composite": {
					"name": "county-boundary + city-boundary",
					"type": "vector",
					"scheme": "xyz",
					"format": "pbf",
					"tilejson": "2.2.0",
					"mapbox_logo": false,
					"maxzoom": 12,
					"minzoom": 0,
					"bounds": [
						108.790841,
						24.636323,
						114.261264,
						30.126363
					],
					"tiles": [
						GIS.source + "/tile/{z}/{x}/{y}.vector.pbf"
						// "http://img.ifzm.cn/gis/tile/{z}.{x}.{y}.vector.pbf"
					]
					// "url": "mapbox://ifzm.cjnn1u32v024l2qmzv5qbr34i-30s8t,ifzm.cjnn282t700rt2wt1zl88rvia-3ptil",
            		// "type": "vector"
				}
			},
			// "sprite": "mapbox://sprites/ifzm/cjnbezsim0bh62sqqiao9g3vc",
			// "glyphs": "mapbox://fonts/ifzm/{fontstack}/{range}.pbf",
			"sprite": GIS.source + "/sprite/sprite",
			"glyphs": GIS.source + "/font/{fontstack}/{range}.pbf",
			// "sprite": "https://lpy-res.oss-cn-shenzhen.aliyuncs.com/hntq/gis/sprite/sprite",
			// "glyphs": "https://lpy-res.oss-cn-shenzhen.aliyuncs.com/hntq/gis/fonts/{fontstack}/{range}.pbf",
			"layers": [{
					"id": "background",
					"type": "background",
					"layout": {},
					"paint": {
						"background-color": "rgba(0,0,0,0)"
					}
				},
				{
					"id": "city-boundary",
					"type": "line",
					"source": "composite",
					"source-layer": "city-boundary",
					"filter": ["in", "$type", "LineString", "Point", "Polygon"],
					"layout": {},
					"paint": {
						"line-color": "hsl(0, 0%, 86%)"
					}
				},
				{
					"id": "county-boundary",
					"type": "line",
					"source": "composite",
					"source-layer": "county-boundary",
					"minzoom": 7,
					"layout": {},
					"paint": {
						"line-color": "hsl(0, 0%, 89%)"
					}
				}
			]
		}
	}, options)

	var map = new mapboxgl.Map(options)
	map.once('styledata', function() {
		map.touchZoomRotate.disableRotation()

		map.addLayer(Utils.createDefaultTextLayerOptions(GeoJSON.city.name, GeoJSON.city.json, {
			layout: {
				"text-offset": {
					"type": "identity",
					"property": "offset"
				}
			}
		}))
		map.addLayer(Utils.createDefaultTextLayerOptions(GeoJSON.cnty.name, GeoJSON.cnty.json, {
			layout: {
				"text-offset": [0, -0.5]
			}
		}), GeoJSON.city.name)
		map.addLayer(Utils.createDefaultTextLayerOptions(GeoJSON.station.name, GeoJSON.station.json, {
			layout: {
				"text-offset": [0, -0.5]
			}
		}), GeoJSON.cnty.name)
		map.setLayerZoomRange(GeoJSON.city.name, 4, 7)
		map.setLayerZoomRange(GeoJSON.cnty.name, 7, 9)
		map.setLayerZoomRange(GeoJSON.station.name, 9, 21)

		$.getJSON(GIS.path + 'geojson/hu-nan-sheng.json', function(json) {
			// 如需绘制色斑图，需要添加一个遮罩层
			if (options.spot) {
				map.addLayer({
					"id": "hu-nan-sheng-fill",
					"type": "fill",
					"source": {
						"type": "geojson",
						"data": json
					},
					"paint": {
						"fill-color": "#ffffff",
						"fill-opacity": 1
					}
				}, GeoJSON.station.name)
			}

			map.addLayer({
				"id": "hu-nan-sheng-line",
				"type": "line",
				"source": {
					"type": "geojson",
					"data": json
				},
				"paint": {
					"line-color": "#afafaf",
					"line-width": 1.5
				}
			}, GeoJSON.station.name)
		})
		
		options.load && options.load(map)
	})

	map.on('load', function() {
		setTimeout(function() {
			mui.hideLoading && mui.hideLoading()
		}, 500)
	})

	return (GIS.map = map, map)
}

var GIS = window.GIS = {
	map: undefined,
	init: init,
	utils: Utils,
	geo: GeoJSON,
	path: $('#gis').attr('src').replace('mapbox-gl.js', ''),
	amapKey: '568ee8033ec64362910893e22980da60',
	source: (mui.os.plus ? localStorage.localPath : location.origin) + '/libs/gis',
	defaults: {
		blankImageURI: 'http://img.ifzm.cn/tm.png'
	}
}
